@@ -131,22 +131,22 @@ CL_ParseStartSoundPacket
 */
 void CL_ParseStartSoundPacket(void)
 {
-    vec3_t  pos;
-    int 	channel, ent;
-    int 	sound_num;
-    int 	volume;
-    int 	field_mask;
-    float 	attenuation;
- 	int		i;
+	vec3_t	pos;
+	int	channel, ent;
+	int	sound_num;
+	int	volume;
+	int	field_mask;
+	float	attenuation;
+	int	i;
 
-    field_mask = MSG_ReadByte();
+	field_mask = MSG_ReadByte();
 
-    if (field_mask & SND_VOLUME)
+	if (field_mask & SND_VOLUME)
 		volume = MSG_ReadByte ();
 	else
 		volume = DEFAULT_SOUND_PACKET_VOLUME;
 
-    if (field_mask & SND_ATTENUATION)
+	if (field_mask & SND_ATTENUATION)
 		attenuation = MSG_ReadByte () / 64.0;
 	else
 		attenuation = DEFAULT_SOUND_PACKET_ATTENUATION;
@@ -178,10 +178,10 @@ void CL_ParseStartSoundPacket(void)
 	if (ent > cl_max_edicts) //johnfitz -- no more MAX_EDICTS
 		Host_Error ("CL_ParseStartSoundPacket: ent = %i", ent);
 
-	for (i=0 ; i<3 ; i++)
+	for (i = 0; i < 3; i++)
 		pos[i] = MSG_ReadCoord ();
 
-    S_StartSound (ent, channel, cl.sound_precache[sound_num], pos, volume/255.0, attenuation);
+	S_StartSound (ent, channel, cl.sound_precache[sound_num], pos, volume/255.0, attenuation);
 }
 
 /*
@@ -192,13 +192,14 @@ When the client is taking a long time to load stuff, send keepalive messages
 so the server doesn't disconnect.
 ==================
 */
+static byte	net_olddata[NET_MAXMESSAGE];
 void CL_KeepaliveMessage (void)
 {
 	float	time;
 	static float lastmsg;
 	int		ret;
 	sizebuf_t	old;
-	byte		olddata[8192];
+	byte	*olddata;
 
 	if (sv.active)
 		return;		// no need if server is local
@@ -206,6 +207,7 @@ void CL_KeepaliveMessage (void)
 		return;
 
 // read messages from server, should just be nops
+	olddata = net_olddata;
 	old = net_message;
 	memcpy (olddata, net_message.data, net_message.cursize);
 
@@ -232,7 +234,7 @@ void CL_KeepaliveMessage (void)
 	memcpy (net_message.data, olddata, net_message.cursize);
 
 // check time
-	time = Sys_FloatTime ();
+	time = Sys_DoubleTime ();
 	if (time - lastmsg < 5)
 		return;
 	lastmsg = time;
@@ -288,7 +290,7 @@ void CL_ParseServerInfo (void)
 
 // parse signon message
 	str = MSG_ReadString ();
-	strncpy (cl.levelname, str, sizeof(cl.levelname)-1);
+	q_strlcpy (cl.levelname, str, sizeof(cl.levelname));
 
 // seperate the printfs so the server message can have a color
 	Con_Printf ("\n%s\n", Con_Quakebar(40)); //johnfitz
@@ -303,7 +305,7 @@ void CL_ParseServerInfo (void)
 
 // precache models
 	memset (cl.model_precache, 0, sizeof(cl.model_precache));
-	for (nummodels=1 ; ; nummodels++)
+	for (nummodels = 1 ; ; nummodels++)
 	{
 		str = MSG_ReadString ();
 		if (!str[0])
@@ -313,7 +315,7 @@ void CL_ParseServerInfo (void)
 			Con_Printf ("Server sent too many model precaches\n");
 			return;
 		}
-		strcpy (model_precache[nummodels], str);
+		q_strlcpy (model_precache[nummodels], str, MAX_QPATH);
 		Mod_TouchModel (str);
 	}
 
@@ -324,7 +326,7 @@ void CL_ParseServerInfo (void)
 
 // precache sounds
 	memset (cl.sound_precache, 0, sizeof(cl.sound_precache));
-	for (numsounds=1 ; ; numsounds++)
+	for (numsounds = 1 ; ; numsounds++)
 	{
 		str = MSG_ReadString ();
 		if (!str[0])
@@ -334,7 +336,7 @@ void CL_ParseServerInfo (void)
 			Con_Printf ("Server sent too many sound precaches\n");
 			return;
 		}
-		strcpy (sound_precache[numsounds], str);
+		q_strlcpy (sound_precache[numsounds], str, MAX_QPATH);
 		S_TouchSound (str);
 	}
 
@@ -348,9 +350,9 @@ void CL_ParseServerInfo (void)
 //
 
 	// copy the naked name of the map file to the cl structure -- O.S
-	COM_StripExtension (COM_SkipPath(model_precache[1]), cl.mapname);
+	COM_StripExtension (COM_SkipPath(model_precache[1]), cl.mapname, sizeof(cl.mapname));
 
-	for (i=1 ; i<nummodels ; i++)
+	for (i = 1; i < nummodels; i++)
 	{
 		cl.model_precache[i] = Mod_ForName (model_precache[i], false);
 		if (cl.model_precache[i] == NULL)
@@ -362,14 +364,13 @@ void CL_ParseServerInfo (void)
 	}
 
 	S_BeginPrecaching ();
-	for (i=1 ; i<numsounds ; i++)
+	for (i = 1; i < numsounds; i++)
 	{
 		cl.sound_precache[i] = S_PrecacheSound (sound_precache[i]);
 		CL_KeepaliveMessage ();
 	}
 	S_EndPrecaching ();
 
-
 // local state
 	cl_entities[0].model = cl.worldmodel = cl.model_precache[1];
 
@@ -401,17 +402,15 @@ If an entities model or origin changes from frame to frame, it must be
 relinked.  Other attributes can change without relinking.
 ==================
 */
-int	bitcounts[16];
-
 void CL_ParseUpdate (int bits)
 {
-	int			i;
+	int		i;
 	model_t		*model;
-	int			modnum;
+	int		modnum;
 	qboolean	forcelink;
 	entity_t	*ent;
-	int			num;
-	int			skin;
+	int		num;
+	int		skin;
 
 	if (cls.signon == SIGNONS - 1)
 	{	// first update is the final signon stage
@@ -442,10 +441,6 @@ void CL_ParseUpdate (int bits)
 
 	ent = CL_EntityNum (num);
 
-	for (i=0 ; i<16 ; i++)
-		if (bits&(1<<i))
-			bitcounts[i]++;
-
 	if (ent->msgtime != cl.mtime[1])
 		forcelink = true;	// no previous frame to lerp from
 	else
@@ -488,7 +483,8 @@ void CL_ParseUpdate (int bits)
 		skin = MSG_ReadByte();
 	else
 		skin = ent->baseline.skin;
-	if (skin != ent->skinnum) {
+	if (skin != ent->skinnum)
+	{
 		ent->skinnum = skin;
 		if (num > 0 && num <= cl.maxclients)
 			R_TranslateNewPlayerSkin (num - 1); //johnfitz -- was R_TranslatePlayerSkin
@@ -530,7 +526,7 @@ void CL_ParseUpdate (int bits)
 		ent->msg_angles[0][2] = ent->baseline.angles[2];
 
 	//johnfitz -- lerping for movetype_step entities
-	if ( bits & U_STEP )
+	if (bits & U_STEP)
 	{
 		ent->lerpflags |= LERP_MOVESTEP;
 		ent->forcelink = true;
@@ -563,9 +559,10 @@ void CL_ParseUpdate (int bits)
 		//HACK: if this bit is set, assume this is PROTOCOL_NEHAHRA
 		if (bits & U_TRANS)
 		{
-			float a,b;
+			float a, b;
 
-			if (warn_about_nehahra_protocol) {
+			if (warn_about_nehahra_protocol)
+			{
 				Con_Warning ("nonstandard update bit, assuming Nehahra protocol\n");
 				warn_about_nehahra_protocol = false;
 			}
@@ -632,7 +629,7 @@ void CL_ParseBaseline (entity_t *ent, int version) //johnfitz -- added argument
 
 	ent->baseline.colormap = MSG_ReadByte();
 	ent->baseline.skin = MSG_ReadByte();
-	for (i=0 ; i<3 ; i++)
+	for (i = 0; i < 3; i++)
 	{
 		ent->baseline.origin[i] = MSG_ReadCoord ();
 		ent->baseline.angles[i] = MSG_ReadAngle ();
@@ -674,7 +671,7 @@ void CL_ParseClientdata (void)
 		cl.idealpitch = 0;
 
 	VectorCopy (cl.mvelocity[0], cl.mvelocity[1]);
-	for (i=0 ; i<3 ; i++)
+	for (i = 0; i < 3; i++)
 	{
 		if (bits & (SU_PUNCH1<<i) )
 			cl.punchangle[i] = MSG_ReadChar();
@@ -701,7 +698,7 @@ void CL_ParseClientdata (void)
 	if (cl.items != i)
 	{	// set flash times
 		Sbar_Changed ();
-		for (j=0 ; j<32 ; j++)
+		for (j = 0; j < 32; j++)
 			if ( (i & (1<<j)) && !(cl.items & (1<<j)))
 				cl.item_gettime[j] = cl.time;
 		cl.items = i;
@@ -754,7 +751,7 @@ void CL_ParseClientdata (void)
 		Sbar_Changed ();
 	}
 
-	for (i=0 ; i<4 ; i++)
+	for (i = 0; i < 4; i++)
 	{
 		j = MSG_ReadByte ();
 		if (cl.stats[STAT_SHELLS+i] != j)
@@ -827,19 +824,23 @@ void CL_NewTranslation (int slot)
 	bottom = (cl.scores[slot].colors &15)<<4;
 	R_TranslatePlayerSkin (slot);
 
-	for (i=0 ; i<VID_GRADES ; i++, dest += 256, source+=256)
+	for (i = 0; i < VID_GRADES; i++, dest += 256, source+=256)
 	{
 		if (top < 128)	// the artists made some backwards ranges.  sigh.
 			memcpy (dest + TOP_RANGE, source + top, 16);
 		else
-			for (j=0 ; j<16 ; j++)
+		{
+			for (j = 0; j < 16; j++)
 				dest[TOP_RANGE+j] = source[top+15-j];
+		}
 
 		if (bottom < 128)
 			memcpy (dest + BOTTOM_RANGE, source + bottom, 16);
 		else
-			for (j=0 ; j<16 ; j++)
+		{
+			for (j = 0; j < 16; j++)
 				dest[BOTTOM_RANGE+j] = source[bottom+15-j];
+		}
 	}
 }
 
@@ -888,7 +889,7 @@ void CL_ParseStaticSound (int version) //johnfitz -- added argument
 	int			sound_num, vol, atten;
 	int			i;
 
-	for (i=0 ; i<3 ; i++)
+	for (i = 0; i < 3; i++)
 		org[i] = MSG_ReadCoord ();
 
 	//johnfitz -- PROTOCOL_FITZQUAKE
@@ -965,7 +966,7 @@ void CL_ParseServerMessage (void)
 			break;
 
 		case svc_nop:
-//			Con_Printf ("svc_nop\n");
+		//	Con_Printf ("svc_nop\n");
 			break;
 
 		case svc_time:
@@ -1002,6 +1003,8 @@ void CL_ParseServerMessage (void)
 			break;
 
 		case svc_stufftext:
+			cls.stufftext_frame = host_framecount;	// allow full frame update
+								// in demo playback -- Pa3PyX
 			Cbuf_AddText (MSG_ReadString ());
 			break;
 
@@ -1027,7 +1030,7 @@ void CL_ParseServerMessage (void)
 			i = MSG_ReadByte ();
 			if (i >= MAX_LIGHTSTYLES)
 				Sys_Error ("svc_lightstyle > MAX_LIGHTSTYLES");
-			Q_strcpy (cl_lightstyle[i].map,  MSG_ReadString());
+			q_strlcpy (cl_lightstyle[i].map, MSG_ReadString(), MAX_STYLESTRING);
 			cl_lightstyle[i].length = Q_strlen(cl_lightstyle[i].map);
 			//johnfitz -- save extra info
 			if (cl_lightstyle[i].length)
@@ -1060,7 +1063,7 @@ void CL_ParseServerMessage (void)
 			i = MSG_ReadByte ();
 			if (i >= cl.maxclients)
 				Host_Error ("CL_ParseServerMessage: svc_updatename > MAX_SCOREBOARD");
-			strcpy (cl.scores[i].name, MSG_ReadString ());
+			q_strlcpy (cl.scores[i].name, MSG_ReadString(), MAX_SCOREBOARDNAME);
 			break;
 
 		case svc_updatefrags:
@@ -1099,19 +1102,16 @@ void CL_ParseServerMessage (void)
 			break;
 
 		case svc_setpause:
+			cl.paused = MSG_ReadByte ();
+			if (cl.paused)
 			{
-				cl.paused = MSG_ReadByte ();
-
-				if (cl.paused)
-				{
-					CDAudio_Pause ();
-					BGM_Pause ();
-				}
-				else
-				{
-					CDAudio_Resume ();
-					BGM_Resume ();
-				}
+				CDAudio_Pause ();
+				BGM_Pause ();
+			}
+			else
+			{
+				CDAudio_Resume ();
+				BGM_Resume ();
 			}
 			break;
 
@@ -1223,3 +1223,4 @@ void CL_ParseServerMessage (void)
 		lastcmd = cmd; //johnfitz
 	}
 }
+
