@@ -23,23 +23,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "quakedef.h"
 #include <errno.h>
 
-static char     *largv[MAX_NUM_ARGVS + 1];
-static char     argvdummy[] = " ";
+static char	*largv[MAX_NUM_ARGVS + 1];
+static char	argvdummy[] = " ";
 
-int             safemode;
+int		safemode;
 
-cvar_t  registered = {"registered","0"};
-cvar_t  cmdline = {"cmdline","", false, true};
+cvar_t	registered = {"registered","0",CVAR_ROM};
+cvar_t	cmdline = {"cmdline","",CVAR_ROM/*|CVAR_SERVERINFO*/}; /* sending cmdline upon CCREQ_RULE_INFO is evil */
 
-qboolean        com_modified;   // set true if using non-id files
+qboolean	com_modified;	// set true if using non-id files
 
-int com_nummissionpacks; //johnfitz
-
-int             static_registered = 1;  // only for startup check, then set
+int	com_nummissionpacks; //johnfitz
 
 qboolean		fitzmode;
 
-void COM_InitFilesystem (void);
+static void COM_Path_f (void);
 
 // if a packfile directory differs from this, it is assumed to be hacked
 #define PAK0_COUNT              339
@@ -49,35 +47,34 @@ char	com_token[1024];
 int		com_argc;
 char	**com_argv;
 
-#define CMDLINE_LENGTH	256 //johnfitz -- mirrored in cmd.c
+#define CMDLINE_LENGTH	256		/* johnfitz -- mirrored in cmd.c */
 char	com_cmdline[CMDLINE_LENGTH];
 
 qboolean standard_quake = true, rogue, hipnotic;
 
 // this graphic needs to be in the pak file to use registered features
-unsigned short pop[] =
+static unsigned short pop[] =
 {
- 0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
-,0x0000,0x0000,0x6600,0x0000,0x0000,0x0000,0x6600,0x0000
-,0x0000,0x0066,0x0000,0x0000,0x0000,0x0000,0x0067,0x0000
-,0x0000,0x6665,0x0000,0x0000,0x0000,0x0000,0x0065,0x6600
-,0x0063,0x6561,0x0000,0x0000,0x0000,0x0000,0x0061,0x6563
-,0x0064,0x6561,0x0000,0x0000,0x0000,0x0000,0x0061,0x6564
-,0x0064,0x6564,0x0000,0x6469,0x6969,0x6400,0x0064,0x6564
-,0x0063,0x6568,0x6200,0x0064,0x6864,0x0000,0x6268,0x6563
-,0x0000,0x6567,0x6963,0x0064,0x6764,0x0063,0x6967,0x6500
-,0x0000,0x6266,0x6769,0x6a68,0x6768,0x6a69,0x6766,0x6200
-,0x0000,0x0062,0x6566,0x6666,0x6666,0x6666,0x6562,0x0000
-,0x0000,0x0000,0x0062,0x6364,0x6664,0x6362,0x0000,0x0000
-,0x0000,0x0000,0x0000,0x0062,0x6662,0x0000,0x0000,0x0000
-,0x0000,0x0000,0x0000,0x0061,0x6661,0x0000,0x0000,0x0000
-,0x0000,0x0000,0x0000,0x0000,0x6500,0x0000,0x0000,0x0000
-,0x0000,0x0000,0x0000,0x0000,0x6400,0x0000,0x0000,0x0000
+	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x6600,0x0000,0x0000,0x0000,0x6600,0x0000,
+	0x0000,0x0066,0x0000,0x0000,0x0000,0x0000,0x0067,0x0000,
+	0x0000,0x6665,0x0000,0x0000,0x0000,0x0000,0x0065,0x6600,
+	0x0063,0x6561,0x0000,0x0000,0x0000,0x0000,0x0061,0x6563,
+	0x0064,0x6561,0x0000,0x0000,0x0000,0x0000,0x0061,0x6564,
+	0x0064,0x6564,0x0000,0x6469,0x6969,0x6400,0x0064,0x6564,
+	0x0063,0x6568,0x6200,0x0064,0x6864,0x0000,0x6268,0x6563,
+	0x0000,0x6567,0x6963,0x0064,0x6764,0x0063,0x6967,0x6500,
+	0x0000,0x6266,0x6769,0x6a68,0x6768,0x6a69,0x6766,0x6200,
+	0x0000,0x0062,0x6566,0x6666,0x6666,0x6666,0x6562,0x0000,
+	0x0000,0x0000,0x0062,0x6364,0x6664,0x6362,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0062,0x6662,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0061,0x6661,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x6500,0x0000,0x0000,0x0000,
+	0x0000,0x0000,0x0000,0x0000,0x6400,0x0000,0x0000,0x0000
 };
 
 /*
 
-
 All of Quake's data access is through a hierchal file system, but the contents
 of the file system can be transparently merged from several sources.
 
@@ -130,6 +127,7 @@ void InsertLinkBefore (link_t *l, link_t *before)
 	l->prev->next = l;
 	l->next->prev = l;
 }
+
 void InsertLinkAfter (link_t *l, link_t *after)
 {
 	l->next = after->next;
@@ -154,7 +152,8 @@ int q_vsnprintf(char *str, size_t size, const char *format, va_list args)
 
 	if (ret < 0)
 		ret = (int)size;
-
+	if (size == 0)	/* no buffer */
+		return ret;
 	if ((size_t)ret >= size)
 		str[size - 1] = '\0';
 
@@ -181,11 +180,11 @@ void Q_memset (void *dest, int fill, size_t count)
 	{
 		count >>= 2;
 		fill = fill | (fill<<8) | (fill<<16) | (fill<<24);
-		for (i=0 ; i<count ; i++)
+		for (i = 0; i < count; i++)
 			((int *)dest)[i] = fill;
 	}
 	else
-		for (i=0 ; i<count ; i++)
+		for (i = 0; i < count; i++)
 			((byte *)dest)[i] = fill;
 }
 
@@ -195,12 +194,12 @@ void Q_memcpy (void *dest, const void *src, size_t count)
 
 	if (( ( (size_t)dest | (size_t)src | count) & 3) == 0 )
 	{
-		count>>=2;
-		for (i=0 ; i<count ; i++)
+		count >>= 2;
+		for (i = 0; i < count; i++)
 			((int *)dest)[i] = ((int *)src)[i];
 	}
 	else
-		for (i=0 ; i<count ; i++)
+		for (i = 0; i < count; i++)
 			((byte *)dest)[i] = ((byte *)src)[i];
 }
 
@@ -236,7 +235,7 @@ void Q_strncpy (char *dest, const char *src, int count)
 
 int Q_strlen (const char *str)
 {
-	int             count;
+	int		count;
 
 	count = 0;
 	while (str[count])
@@ -247,11 +246,14 @@ int Q_strlen (const char *str)
 
 char *Q_strrchr(const char *s, char c)
 {
-    int len = Q_strlen(s);
-    s += len;
-    while (len--)
-	if (*--s == c) return (char *)s;
-    return NULL;
+	int len = Q_strlen(s);
+	s += len;
+	while (len--)
+	{
+		if (*--s == c)
+			return (char *)s;
+	}
+	return NULL;
 }
 
 void Q_strcat (char *dest, const char *src)
@@ -265,9 +267,9 @@ int Q_strcmp (const char *s1, const char *s2)
 	while (1)
 	{
 		if (*s1 != *s2)
-			return -1;              // strings not equal
+			return -1;		// strings not equal
 		if (!*s1)
-			return 0;               // strings are equal
+			return 0;		// strings are equal
 		s1++;
 		s2++;
 	}
@@ -282,9 +284,9 @@ int Q_strncmp (const char *s1, const char *s2, int count)
 		if (!count--)
 			return 0;
 		if (*s1 != *s2)
-			return -1;              // strings not equal
+			return -1;		// strings not equal
 		if (!*s1)
-			return 0;               // strings are equal
+			return 0;		// strings are equal
 		s1++;
 		s2++;
 	}
@@ -294,7 +296,7 @@ int Q_strncmp (const char *s1, const char *s2, int count)
 
 int Q_strncasecmp (const char *s1, const char *s2, int n)
 {
-	int             c1, c2;
+	int		c1, c2;
 
 	if (s1 == s2 || n <= 0)
 		return 0;
@@ -305,7 +307,7 @@ int Q_strncasecmp (const char *s1, const char *s2, int n)
 		c2 = *s2++;
 
 		if (!n--)
-			return 0;               // strings are equal until end point
+			return 0;		// strings are equal until end point
 
 		if (c1 != c2)
 		{
@@ -330,9 +332,9 @@ int Q_strcasecmp (const char *s1, const char *s2)
 
 int Q_atoi (const char *str)
 {
-	int             val;
-	int             sign;
-	int             c;
+	int		val;
+	int		sign;
+	int		c;
 
 	if (*str == '-')
 	{
@@ -389,10 +391,10 @@ int Q_atoi (const char *str)
 
 float Q_atof (const char *str)
 {
-	double			val;
-	int             sign;
-	int             c;
-	int             decimal, total;
+	double		val;
+	int		sign;
+	int		c;
+	int	decimal, total;
 
 	if (*str == '-')
 	{
@@ -470,18 +472,18 @@ float Q_atof (const char *str)
 ============================================================================
 */
 
-qboolean        bigendien;
+qboolean	host_bigendian;
 
-short   (*BigShort) (short l);
-short   (*LittleShort) (short l);
-int     (*BigLong) (int l);
-int     (*LittleLong) (int l);
-float   (*BigFloat) (float l);
-float   (*LittleFloat) (float l);
+short	(*BigShort) (short l);
+short	(*LittleShort) (short l);
+int	(*BigLong) (int l);
+int	(*LittleLong) (int l);
+float	(*BigFloat) (float l);
+float	(*LittleFloat) (float l);
 
-short   ShortSwap (short l)
+short ShortSwap (short l)
 {
-	byte    b1,b2;
+	byte	b1, b2;
 
 	b1 = l&255;
 	b2 = (l>>8)&255;
@@ -489,14 +491,14 @@ short   ShortSwap (short l)
 	return (b1<<8) + b2;
 }
 
-short   ShortNoSwap (short l)
+short ShortNoSwap (short l)
 {
 	return l;
 }
 
-int    LongSwap (int l)
+int LongSwap (int l)
 {
-	byte    b1,b2,b3,b4;
+	byte	b1, b2, b3, b4;
 
 	b1 = l&255;
 	b2 = (l>>8)&255;
@@ -506,7 +508,7 @@ int    LongSwap (int l)
 	return ((int)b1<<24) + ((int)b2<<16) + ((int)b3<<8) + b4;
 }
 
-int     LongNoSwap (int l)
+int LongNoSwap (int l)
 {
 	return l;
 }
@@ -515,8 +517,8 @@ float FloatSwap (float f)
 {
 	union
 	{
-		float   f;
-		byte    b[4];
+		float	f;
+		byte	b[4];
 	} dat1, dat2;
 
 
@@ -548,7 +550,7 @@ Handles byte ordering and avoids alignment errors
 
 void MSG_WriteChar (sizebuf_t *sb, int c)
 {
-	byte    *buf;
+	byte	*buf;
 
 #ifdef PARANOID
 	if (c < -128 || c > 127)
@@ -561,7 +563,7 @@ void MSG_WriteChar (sizebuf_t *sb, int c)
 
 void MSG_WriteByte (sizebuf_t *sb, int c)
 {
-	byte    *buf;
+	byte	*buf;
 
 #ifdef PARANOID
 	if (c < 0 || c > 255)
@@ -574,7 +576,7 @@ void MSG_WriteByte (sizebuf_t *sb, int c)
 
 void MSG_WriteShort (sizebuf_t *sb, int c)
 {
-	byte    *buf;
+	byte	*buf;
 
 #ifdef PARANOID
 	if (c < ((short)0x8000) || c > (short)0x7fff)
@@ -588,7 +590,7 @@ void MSG_WriteShort (sizebuf_t *sb, int c)
 
 void MSG_WriteLong (sizebuf_t *sb, int c)
 {
-	byte    *buf;
+	byte	*buf;
 
 	buf = (byte *) SZ_GetSpace (sb, 4);
 	buf[0] = c&0xff;
@@ -601,11 +603,10 @@ void MSG_WriteFloat (sizebuf_t *sb, float f)
 {
 	union
 	{
-		float   f;
-		int     l;
+		float	f;
+		int	l;
 	} dat;
 
-
 	dat.f = f;
 	dat.l = LittleLong (dat.l);
 
@@ -659,8 +660,8 @@ void MSG_WriteAngle16 (sizebuf_t *sb, float f)
 //
 // reading functions
 //
-int                     msg_readcount;
-qboolean        msg_badread;
+int		msg_readcount;
+qboolean	msg_badread;
 
 void MSG_BeginReading (void)
 {
@@ -671,7 +672,7 @@ void MSG_BeginReading (void)
 // returns -1 and sets msg_badread if no more characters are available
 int MSG_ReadChar (void)
 {
-	int     c;
+	int	c;
 
 	if (msg_readcount+1 > net_message.cursize)
 	{
@@ -687,7 +688,7 @@ int MSG_ReadChar (void)
 
 int MSG_ReadByte (void)
 {
-	int     c;
+	int	c;
 
 	if (msg_readcount+1 > net_message.cursize)
 	{
@@ -703,7 +704,7 @@ int MSG_ReadByte (void)
 
 int MSG_ReadShort (void)
 {
-	int     c;
+	int	c;
 
 	if (msg_readcount+2 > net_message.cursize)
 	{
@@ -721,7 +722,7 @@ int MSG_ReadShort (void)
 
 int MSG_ReadLong (void)
 {
-	int     c;
+	int	c;
 
 	if (msg_readcount+4 > net_message.cursize)
 	{
@@ -743,15 +744,15 @@ float MSG_ReadFloat (void)
 {
 	union
 	{
-		byte    b[4];
-		float   f;
-		int     l;
+		byte	b[4];
+		float	f;
+		int	l;
 	} dat;
 
-	dat.b[0] =      net_message.data[msg_readcount];
-	dat.b[1] =      net_message.data[msg_readcount+1];
-	dat.b[2] =      net_message.data[msg_readcount+2];
-	dat.b[3] =      net_message.data[msg_readcount+3];
+	dat.b[0] = net_message.data[msg_readcount];
+	dat.b[1] = net_message.data[msg_readcount+1];
+	dat.b[2] = net_message.data[msg_readcount+2];
+	dat.b[3] = net_message.data[msg_readcount+3];
 	msg_readcount += 4;
 
 	dat.l = LittleLong (dat.l);
@@ -761,8 +762,9 @@ float MSG_ReadFloat (void)
 
 const char *MSG_ReadString (void)
 {
-	static char     string[2048];
-	int             l,c;
+	static char	string[2048];
+	int		c;
+	size_t		l;
 
 	l = 0;
 	do
@@ -772,7 +774,7 @@ const char *MSG_ReadString (void)
 			break;
 		string[l] = c;
 		l++;
-	} while (l < sizeof(string)-1);
+	} while (l < sizeof(string) - 1);
 
 	string[l] = 0;
 
@@ -814,8 +816,6 @@ float MSG_ReadAngle16 (void)
 }
 //johnfitz
 
-
-
 //===========================================================================
 
 void SZ_Alloc (sizebuf_t *buf, int startsize)
@@ -830,9 +830,9 @@ void SZ_Alloc (sizebuf_t *buf, int startsize)
 
 void SZ_Free (sizebuf_t *buf)
 {
-//      Z_Free (buf->data);
-//      buf->data = NULL;
-//      buf->maxsize = 0;
+//	Z_Free (buf->data);
+//	buf->data = NULL;
+//	buf->maxsize = 0;
 	buf->cursize = 0;
 }
 
@@ -843,7 +843,7 @@ void SZ_Clear (sizebuf_t *buf)
 
 void *SZ_GetSpace (sizebuf_t *buf, int length)
 {
-	void    *data;
+	void	*data;
 
 	if (buf->cursize + length > buf->maxsize)
 	{
@@ -871,9 +871,9 @@ void SZ_Write (sizebuf_t *buf, const void *data, int length)
 
 void SZ_Print (sizebuf_t *buf, const char *data)
 {
-	int             len;
+	int		len;
 
-	len = Q_strlen(data)+1;
+	len = Q_strlen(data) + 1;
 
 // byte * cast to keep VC++ happy
 	if (buf->data[buf->cursize-1])
@@ -885,7 +885,6 @@ void SZ_Print (sizebuf_t *buf, const char *data)
 
 //============================================================================
 
-
 /*
 ============
 COM_SkipPath
@@ -893,13 +892,13 @@ COM_SkipPath
 */
 const char *COM_SkipPath (const char *pathname)
 {
-	const char *last;
+	const char	*last;
 
 	last = pathname;
 	while (*pathname)
 	{
-		if (*pathname=='/')
-			last = pathname+1;
+		if (*pathname == '/')
+			last = pathname + 1;
 		pathname++;
 	}
 	return last;
@@ -910,84 +909,128 @@ const char *COM_SkipPath (const char *pathname)
 COM_StripExtension
 ============
 */
-void COM_StripExtension (const char *in, char *out)
+void COM_StripExtension (const char *in, char *out, size_t outsize)
 {
-	while (*in && *in != '.')
-		*out++ = *in++;
-	*out = 0;
+	int	length;
+
+	if (!*in)
+	{
+		*out = '\0';
+		return;
+	}
+	if (in != out)	/* copy when not in-place editing */
+		q_strlcpy (out, in, outsize);
+	length = (int)strlen(out) - 1;
+	while (length > 0 && out[length] != '.')
+	{
+		--length;
+		if (out[length] == '/' || out[length] == '\\')
+			return;	/* no extension */
+	}
+	if (length > 0)
+		out[length] = '\0';
 }
 
 /*
 ============
-COM_FileExtension
+COM_FileGetExtension - doesn't return NULL
 ============
 */
-const char *COM_FileExtension (const char *in)
+const char *COM_FileGetExtension (const char *in)
 {
-	static char exten[8];
-	int             i;
+	const char	*src;
+	size_t		len;
 
-	while (*in && *in != '.')
-		in++;
-	if (!*in)
+	len = strlen(in);
+	if (len < 2)	/* nothing meaningful */
 		return "";
-	in++;
-	for (i=0 ; i<7 && *in ; i++,in++)
-		exten[i] = *in;
-	exten[i] = 0;
-	return exten;
+
+	src = in + len - 1;
+	while (src != in && src[-1] != '.')
+		src--;
+	if (src == in || strchr(src, '/') != NULL || strchr(src, '\\') != NULL)
+		return "";	/* no extension, or parent directory has a dot */
+
+	return src;
+}
+
+/*
+============
+COM_ExtractExtension
+============
+*/
+void COM_ExtractExtension (const char *in, char *out, size_t outsize)
+{
+	const char *ext = COM_FileGetExtension (in);
+	if (! *ext)
+		*out = '\0';
+	else
+		q_strlcpy (out, ext, outsize);
 }
 
 /*
 ============
 COM_FileBase
+take 'somedir/otherdir/filename.ext',
+write only 'filename' to the output
 ============
 */
-void COM_FileBase (const char *in, char *out)
+void COM_FileBase (const char *in, char *out, size_t outsize)
 {
-	const char *s, *s2;
+	const char	*dot, *slash, *s;
 
-	s = in + strlen(in) - 1;
+	s = in;
+	slash = in;
+	dot = NULL;
+	while (*s)
+	{
+		if (*s == '/')
+			slash = s + 1;
+		if (*s == '.')
+			dot = s;
+		s++;
+	}
+	if (dot == NULL)
+		dot = s;
 
-	while (s != in && *s != '.')
-		s--;
-
-	for (s2 = s ; s2 != in && *s2 && *s2 != '/' ; s2--)
-	;
-
-	if (s-s2 < 2)
-		strcpy (out,"?model?");
+	if (dot - slash < 2)
+		q_strlcpy (out, "?model?", outsize);
 	else
 	{
-		s--;
-		strncpy (out,s2+1, s-s2);
-		out[s-s2] = 0;
+		size_t	len = dot - slash;
+		if (len >= outsize)
+			len = outsize - 1;
+		memcpy (out, slash, len);
+		out[len] = '\0';
 	}
 }
 
-
 /*
 ==================
 COM_DefaultExtension
 ==================
 */
-void COM_DefaultExtension (char *path, const char *extension)
+void COM_DefaultExtension (char *path, const char *extension, size_t len)
 {
-	char    *src;
+	char	*src;
+	size_t	l;
 //
 // if path doesn't have a .EXT, append extension
 // (extension should include the .)
 //
-	src = path + strlen(path) - 1;
+	if (!*path)
+		return;
+	l = strlen(path);
+	src = path + l - 1;
 
 	while (*src != '/' && src != path)
 	{
 		if (*src == '.')
-			return;                 // it has an extension
+			return;		// it has an extension
 		src--;
 	}
 
-	strcat (path, extension);
+	q_strlcat(path, extension, len);
 }
 
 
@@ -1000,8 +1043,8 @@ Parse a token out of a string
 */
 const char *COM_Parse (const char *data)
 {
-	int             c;
-	int             len;
+	int		c;
+	int		len;
 
 	len = 0;
 	com_token[0] = 0;
@@ -1014,7 +1057,7 @@ skipwhite:
 	while ( (c = *data) <= ' ')
 	{
 		if (c == 0)
-			return NULL;                    // end of file;
+			return NULL;			// end of file;
 		data++;
 	}
 
@@ -1061,9 +1104,9 @@ skipwhite:
 		len++;
 		c = *data;
 		/* commented out the check for ':' so that ip:port works */
-		if (c=='{' || c=='}'|| c==')'|| c=='(' || c=='\'' /* || c==':' */)
+		if (c == '{' || c == '}'|| c == ')'|| c == '(' || c == '\'' /* || c == ':' */)
 			break;
-	} while (c>32);
+	} while (c > 32);
 
 	com_token[len] = 0;
 	return data;
@@ -1080,12 +1123,12 @@ where the given parameter apears, or 0 if not present
 */
 int COM_CheckParm (const char *parm)
 {
-	int             i;
+	int		i;
 
-	for (i=1 ; i<com_argc ; i++)
+	for (i = 1; i < com_argc; i++)
 	{
 		if (!com_argv[i])
-			continue;               // NEXTSTEP sometimes clears appkit vars.
+			continue;		// NEXTSTEP sometimes clears appkit vars.
 		if (!Q_strcmp (parm,com_argv[i]))
 			return i;
 	}
@@ -1103,19 +1146,18 @@ Immediately exits out if an alternate game was attempted to be started without
 being registered.
 ================
 */
-void COM_CheckRegistered (void)
+static void COM_CheckRegistered (void)
 {
-	int             h;
-	unsigned short  check[128];
-	int                     i;
+	int		h;
+	unsigned short	check[128];
+	int		i;
 
 	COM_OpenFile("gfx/pop.lmp", &h, NULL);
-	static_registered = 0;
 
 	if (h == -1)
 	{
 #if WINDED
-	Sys_Error ("This dedicated server requires a full registered copy of Quake");
+		Sys_Error ("This dedicated server requires a full registered copy of Quake");
 #endif
 		Con_Printf ("Playing shareware version.\n");
 		if (com_modified)
@@ -1126,20 +1168,24 @@ void COM_CheckRegistered (void)
 	Sys_FileRead (h, check, sizeof(check));
 	COM_CloseFile (h);
 
-	for (i=0 ; i<128 ; i++)
+	for (i = 0; i < 128; i++)
+	{
 		if (pop[i] != (unsigned short)BigShort (check[i]))
 			Sys_Error ("Corrupted data file.");
+	}
 
-	Cvar_Set ("cmdline", com_cmdline+1); //johnfitz -- eliminate leading space
-	Cvar_Set ("registered", "1");
-	static_registered = 1;
+	for (i = 0; com_cmdline[i]; i++)
+	{
+		if (com_cmdline[i]!= ' ')
+			break;
+	}
+
+	Cvar_SetROM ("cmdline", &com_cmdline[i]);
+	Cvar_SetROM ("registered", "1");
 	Con_Printf ("Playing registered version.\n");
 }
 
 
-void COM_Path_f (void);
-
-
 /*
 ================
 COM_InitArgv
@@ -1147,12 +1193,12 @@ COM_InitArgv
 */
 void COM_InitArgv (int argc, char **argv)
 {
-	int             i, j, n;
+	int		i, j, n;
 
 // reconstitute the command line for the cmdline externally visible cvar
 	n = 0;
 
-	for (j=0 ; (j<MAX_NUM_ARGVS) && (j< argc) ; j++)
+	for (j = 0; (j<MAX_NUM_ARGVS) && (j< argc); j++)
 	{
 		i = 0;
 
@@ -1172,7 +1218,7 @@ void COM_InitArgv (int argc, char **argv)
 
 	Con_Printf("Command line: %s\n", com_cmdline);
 
-	for (com_argc=0 ; (com_argc<MAX_NUM_ARGVS) && (com_argc < argc) ; com_argc++)
+	for (com_argc = 0; (com_argc < MAX_NUM_ARGVS) && (com_argc < argc); com_argc++)
 	{
 		largv[com_argc] = argv[com_argc];
 		if (!Q_strcmp ("-safe", argv[com_argc]))
@@ -1211,7 +1257,7 @@ static void FitzTest_f (void)
 COM_Init
 ================
 */
-void COM_Init (const char *basedir)
+void COM_Init (void)
 {
 	int	i = 0x12345678;
 		/*    U N I X */
@@ -1227,22 +1273,13 @@ void COM_Init (const char *basedir)
 		   N  U  X  I
 	*/
 	if ( *(char *)&i == 0x12 )
-		bigendien = true;
+		host_bigendian = true;
 	else if ( *(char *)&i == 0x78 )
-		bigendien = false;
+		host_bigendian = false;
 	else /* if ( *(char *)&i == 0x34 ) */
 		Sys_Error ("Unsupported endianism.");
 
-	if (bigendien == false)
-	{
-		BigShort = ShortSwap;
-		LittleShort = ShortNoSwap;
-		BigLong = LongSwap;
-		LittleLong = LongNoSwap;
-		BigFloat = FloatSwap;
-		LittleFloat = FloatNoSwap;
-	}
-	else /* we are big endian: */
+	if (host_bigendian)
 	{
 		BigShort = ShortNoSwap;
 		LittleShort = ShortSwap;
@@ -1251,16 +1288,18 @@ void COM_Init (const char *basedir)
 		BigFloat = FloatNoSwap;
 		LittleFloat = FloatSwap;
 	}
+	else /* assumed LITTLE_ENDIAN. */
+	{
+		BigShort = ShortSwap;
+		LittleShort = ShortNoSwap;
+		BigLong = LongSwap;
+		LittleLong = LongNoSwap;
+		BigFloat = FloatSwap;
+		LittleFloat = FloatNoSwap;
+	}
 
 	if (COM_CheckParm("-fitz"))
 		fitzmode = true;
-
-	Cvar_RegisterVariable (&registered, NULL);
-	Cvar_RegisterVariable (&cmdline, NULL);
-	Cmd_AddCommand ("path", COM_Path_f);
-	COM_InitFilesystem ();
-	COM_CheckRegistered ();
-
 #ifdef _DEBUG
 	Cmd_AddCommand ("fitztest", FitzTest_f); //johnfitz
 #endif
@@ -1301,18 +1340,6 @@ char *va (const char *format, ...)
 	return va_buf;
 }
 
-
-/// just for debugging
-int     memsearch (byte *start, int count, int search)
-{
-	int             i;
-
-	for (i=0 ; i<count ; i++)
-		if (start[i] == search)
-			return i;
-	return -1;
-}
-
 /*
 =============================================================================
 
@@ -1321,7 +1348,7 @@ QUAKE FILESYSTEM
 =============================================================================
 */
 
-int     com_filesize;
+int	com_filesize;
 
 
 //
@@ -1330,16 +1357,16 @@ int     com_filesize;
 
 typedef struct
 {
-	char    name[MAX_QPATH];
-	int             filepos, filelen;
+	char	name[MAX_QPATH];
+	int		filepos, filelen;
 } packfile_t;
 
 typedef struct pack_s
 {
-	char    filename[MAX_OSPATH];
-	int             handle;
-	int             numfiles;
-	packfile_t      *files;
+	char	filename[MAX_OSPATH];
+	int		handle;
+	int		numfiles;
+	packfile_t	*files;
 } pack_t;
 
 //
@@ -1347,46 +1374,46 @@ typedef struct pack_s
 //
 typedef struct
 {
-	char    name[56];
-	int             filepos, filelen;
+	char	name[56];
+	int		filepos, filelen;
 } dpackfile_t;
 
 typedef struct
 {
-	char    id[4];
-	int             dirofs;
-	int             dirlen;
+	char	id[4];
+	int		dirofs;
+	int		dirlen;
 } dpackheader_t;
 
-#define MAX_FILES_IN_PACK       2048
+#define MAX_FILES_IN_PACK	2048
 
-char    com_gamedir[MAX_OSPATH];
-char    com_basedir[MAX_OSPATH];
-int     file_from_pak;		// ZOID: global indicating that file came from a pak
+char	com_gamedir[MAX_OSPATH];
+char	com_basedir[MAX_OSPATH];
+int	file_from_pak;		// ZOID: global indicating that file came from a pak
 
 typedef struct searchpath_s
 {
 	unsigned int path_id;	// identifier assigned to the game directory
 					// Note that <install_dir>/game1 and
 					// <userdir>/game1 have the same id.
-	char    filename[MAX_OSPATH];
-	pack_t  *pack;          // only one of filename / pack will be used
-	struct searchpath_s *next;
+	char	filename[MAX_OSPATH];
+	pack_t	*pack;			// only one of filename / pack will be used
+	struct searchpath_s	*next;
 } searchpath_t;
 
-searchpath_t    *com_searchpaths;
+searchpath_t	*com_searchpaths;
 
 /*
 ============
 COM_Path_f
 ============
 */
-void COM_Path_f (void)
+static void COM_Path_f (void)
 {
-	searchpath_t    *s;
+	searchpath_t	*s;
 
 	Con_Printf ("Current search path:\n");
-	for (s=com_searchpaths ; s ; s=s->next)
+	for (s = com_searchpaths; s; s = s->next)
 	{
 		if (s->pack)
 		{
@@ -1406,12 +1433,12 @@ The filename will be prefixed by the current game directory
 */
 void COM_WriteFile (const char *filename, const void *data, int len)
 {
-	int             handle;
-	char    name[MAX_OSPATH];
+	int		handle;
+	char	name[MAX_OSPATH];
 
 	Sys_mkdir (com_gamedir); //johnfitz -- if we've switched to a nonexistant gamedir, create it now so we don't crash
 
-	sprintf (name, "%s/%s", com_gamedir, filename);
+	q_snprintf (name, sizeof(name), "%s/%s", com_gamedir, filename);
 
 	handle = Sys_FileOpenWrite (name);
 	if (handle == -1)
@@ -1430,14 +1457,14 @@ void COM_WriteFile (const char *filename, const void *data, int len)
 COM_CreatePath
 ============
 */
-void    COM_CreatePath (char *path)
+void COM_CreatePath (char *path)
 {
-	char    *ofs;
+	char	*ofs;
 
-	for (ofs = path+1 ; *ofs ; ofs++)
+	for (ofs = path + 1; *ofs; ofs++)
 	{
 		if (*ofs == '/')
-		{       // create the directory
+		{	// create the directory
 			*ofs = 0;
 			Sys_mkdir (path);
 			*ofs = '/';
@@ -1475,11 +1502,10 @@ can be used for detecting a file's presence.
 static int COM_FindFile (const char *filename, int *handle, FILE **file,
 							unsigned int *path_id)
 {
-	searchpath_t    *search;
-	char            netpath[MAX_OSPATH];
-	pack_t          *pak;
-	int                     i;
-	int              findtime;
+	searchpath_t	*search;
+	char		netpath[MAX_OSPATH];
+	pack_t		*pak;
+	int		i, findtime;
 
 	if (file && handle)
 		Sys_Error ("COM_FindFile: both handle and file set");
@@ -1494,7 +1520,7 @@ static int COM_FindFile (const char *filename, int *handle, FILE **file,
 		if (search->pack)	/* look through all the pak file elements */
 		{
 			pak = search->pack;
-			for (i=0 ; i<pak->numfiles ; i++)
+			for (i = 0; i < pak->numfiles; i++)
 			{
 				if (strcmp(pak->files[i].name, filename) != 0)
 					continue;
@@ -1524,13 +1550,13 @@ static int COM_FindFile (const char *filename, int *handle, FILE **file,
 		}
 		else	/* check a file in the directory tree */
 		{
-			if (!static_registered)
+			if (!registered.value)
 			{ /* if not a registered version, don't ever go beyond base */
 				if ( strchr (filename, '/') || strchr (filename,'\\'))
 					continue;
 			}
 
-			sprintf (netpath, "%s/%s",search->filename, filename);
+			q_snprintf (netpath, sizeof(netpath), "%s/%s",search->filename, filename);
 			findtime = Sys_FileTime (netpath);
 			if (findtime == -1)
 				continue;
@@ -1554,10 +1580,12 @@ static int COM_FindFile (const char *filename, int *handle, FILE **file,
 				return 0; /* dummy valid value for COM_FileExists() */
 			}
 		}
-
 	}
 
-	Con_DPrintf ("FindFile: can't find %s\n", filename);
+	if (strcmp(COM_FileGetExtension(filename), "pcx") != 0)
+		Con_DPrintf ("FindFile: can't find %s\n", filename);
+	else	Con_DPrintf2("FindFile: can't find %s\n", filename);
+		// Log pcx texture misses only if (developer.value >= 2)
 
 	if (handle)
 		*handle = -1;
@@ -1617,9 +1645,9 @@ If it is a pak file handle, don't really close it
 */
 void COM_CloseFile (int h)
 {
-	searchpath_t    *s;
+	searchpath_t	*s;
 
-	for (s = com_searchpaths ; s ; s=s->next)
+	for (s = com_searchpaths; s; s = s->next)
 		if (s->pack && s->pack->handle == h)
 			return;
 
@@ -1640,8 +1668,7 @@ Allways appends a 0 byte.
 #define	LOADFILE_TEMPHUNK	2
 #define	LOADFILE_CACHE		3
 #define	LOADFILE_STACK		4
-#define	LOADFILE_BUF		5
-#define	LOADFILE_MALLOC		6
+#define	LOADFILE_MALLOC		5
 
 static byte	*loadbuf;
 static cache_user_t *loadcache;
@@ -1649,12 +1676,12 @@ static int	loadsize;
 
 byte *COM_LoadFile (const char *path, int usehunk, unsigned int *path_id)
 {
-	int             h;
-	byte    *buf;
-	char    base[32];
-	int             len;
+	int		h;
+	byte	*buf;
+	char	base[32];
+	int		len;
 
-	buf = NULL;     // quiet compiler warning
+	buf = NULL;	// quiet compiler warning
 
 // look for it in the filesystem or pack files
 	len = COM_OpenFile (path, &h, path_id);
@@ -1662,7 +1689,7 @@ byte *COM_LoadFile (const char *path, int usehunk, unsigned int *path_id)
 		return NULL;
 
 // extract the filename base name for hunk tag
-	COM_FileBase (path, base);
+	COM_FileBase (path, base, sizeof(base));
 
 	switch (usehunk)
 	{
@@ -1684,12 +1711,6 @@ byte *COM_LoadFile (const char *path, int usehunk, unsigned int *path_id)
 		else
 			buf = (byte *) Hunk_TempAlloc (len+1);
 		break;
-	case LOADFILE_BUF:
-		if (len < loadsize && loadbuf != NULL)
-			buf = loadbuf;
-		else
-			buf = (byte *) Hunk_AllocName(len + 1, base);
-		break;
 	case LOADFILE_MALLOC:
 		buf = (byte *) malloc (len+1);
 		break;
@@ -1732,7 +1753,7 @@ void COM_LoadCacheFile (const char *path, struct cache_user_s *cu, unsigned int
 // uses temp hunk if larger than bufsize
 byte *COM_LoadStackFile (const char *path, void *buffer, int bufsize, unsigned int *path_id)
 {
-	byte    *buf;
+	byte	*buf;
 
 	loadbuf = (byte *)buffer;
 	loadsize = bufsize;
@@ -1741,23 +1762,6 @@ byte *COM_LoadStackFile (const char *path, void *buffer, int bufsize, unsigned i
 	return buf;
 }
 
-// loads into a previously allocated buffer. if space is insufficient
-// or the buffer is NULL, loads onto the hunk.  bufsize is the actual
-// size (without the +1).
-byte *COM_LoadBufFile (const char *path, void *buffer, int *bufsize, unsigned int *path_id)
-{
-	byte	*buf;
-
-	loadbuf = (byte *)buffer;
-	loadsize = (*bufsize) + 1;
-	buf = COM_LoadFile (path, LOADFILE_BUF, path_id);
-	*bufsize = (buf == NULL) ? 0 : com_filesize;
-	if (loadbuf && buf && buf != loadbuf)
-		Sys_Printf("LoadBufFile: insufficient buffer for %s not used.\n", path);
-
-	return buf;
-}
-
 // returns malloc'd memory
 byte *COM_LoadMallocFile (const char *path, unsigned int *path_id)
 {
@@ -1777,14 +1781,14 @@ of the list so they override previous pack files.
 */
 pack_t *COM_LoadPackFile (const char *packfile)
 {
-	dpackheader_t   header;
-	int                             i;
-	packfile_t              *newfiles;
-	int                             numpackfiles;
-	pack_t                  *pack;
-	int                             packhandle;
-	dpackfile_t             info[MAX_FILES_IN_PACK];
-	unsigned short          crc;
+	dpackheader_t	header;
+	int		i;
+	packfile_t	*newfiles;
+	int		numpackfiles;
+	pack_t		*pack;
+	int		packhandle;
+	dpackfile_t	info[MAX_FILES_IN_PACK];
+	unsigned short	crc;
 
 	if (Sys_FileOpenRead (packfile, &packhandle) == -1)
 		return NULL;
@@ -1800,7 +1804,7 @@ pack_t *COM_LoadPackFile (const char *packfile)
 		Sys_Error ("%s has %i files", packfile, numpackfiles);
 
 	if (numpackfiles != PAK0_COUNT)
-		com_modified = true;    // not the original file
+		com_modified = true;	// not the original file
 
 	//johnfitz -- dynamic gamedir loading
 	//Hunk_AllocName (numpackfiles * sizeof(packfile_t), "packfile");
@@ -1812,15 +1816,15 @@ pack_t *COM_LoadPackFile (const char *packfile)
 
 	// crc the directory to check for modifications
 	CRC_Init (&crc);
-	for (i = 0; i < header.dirlen ; i++)
+	for (i = 0; i < header.dirlen; i++)
 		CRC_ProcessByte (&crc, ((byte *)info)[i]);
 	if (crc != PAK0_CRC)
 		com_modified = true;
 
 	// parse the directory
-	for (i = 0; i < numpackfiles ; i++)
+	for (i = 0; i < numpackfiles; i++)
 	{
-		strcpy (newfiles[i].name, info[i].name);
+		q_strlcpy (newfiles[i].name, info[i].name, sizeof(newfiles[i].name));
 		newfiles[i].filepos = LittleLong(info[i].filepos);
 		newfiles[i].filelen = LittleLong(info[i].filelen);
 	}
@@ -1830,7 +1834,7 @@ pack_t *COM_LoadPackFile (const char *packfile)
 	pack = (pack_t *) Z_Malloc (sizeof (pack_t));
 	//johnfitz
 
-	strcpy (pack->filename, packfile);
+	q_strlcpy (pack->filename, packfile, sizeof(pack->filename));
 	pack->handle = packhandle;
 	pack->numfiles = numpackfiles;
 	pack->files = newfiles;
@@ -1844,7 +1848,7 @@ pack_t *COM_LoadPackFile (const char *packfile)
 COM_AddGameDirectory -- johnfitz -- modified based on topaz's tutorial
 =================
 */
-void COM_AddGameDirectory (const char *dir)
+static void COM_AddGameDirectory (const char *dir)
 {
 	int i;
 	unsigned int path_id;
@@ -1852,7 +1856,7 @@ void COM_AddGameDirectory (const char *dir)
 	pack_t *pak;
 	char pakfile[MAX_OSPATH];
 
-	strcpy (com_gamedir, dir);
+	q_strlcpy (com_gamedir, dir, sizeof(com_gamedir));
 
 	// assign a path_id to this game directory
 	if (com_searchpaths)
@@ -1862,14 +1866,14 @@ void COM_AddGameDirectory (const char *dir)
 	// add the directory to the search path
 	search = (searchpath_t *) Z_Malloc(sizeof(searchpath_t));
 	search->path_id = path_id;
-	strcpy (search->filename, dir);
+	q_strlcpy (search->filename, dir, sizeof(search->filename));
 	search->next = com_searchpaths;
 	com_searchpaths = search;
 
 	// add any pak files in the format pak0.pak pak1.pak, ...
 	for (i = 0; ; i++)
 	{
-		sprintf (pakfile, "%s/pak%i.pak", dir, i);
+		q_snprintf (pakfile, sizeof(pakfile), "%s/pak%i.pak", dir, i);
 		pak = COM_LoadPackFile (pakfile);
 		if (!pak)
 			break;
@@ -1915,11 +1919,15 @@ void COM_InitFilesystem (void) //johnfitz -- modified based on topaz's tutorial
 {
 	int i, j;
 
+	Cvar_RegisterVariable (&registered);
+	Cvar_RegisterVariable (&cmdline);
+	Cmd_AddCommand ("path", COM_Path_f);
+
 	i = COM_CheckParm ("-basedir");
 	if (i && i < com_argc-1)
-		strcpy (com_basedir, com_argv[i + 1]);
+		q_strlcpy (com_basedir, com_argv[i + 1], sizeof(com_basedir));
 	else
-		strcpy (com_basedir, host_parms.basedir);
+		q_strlcpy (com_basedir, host_parms->basedir, sizeof(com_basedir));
 
 	j = strlen (com_basedir);
 	if (j > 0)
@@ -1930,7 +1938,7 @@ void COM_InitFilesystem (void) //johnfitz -- modified based on topaz's tutorial
 
 	// start up with GAMENAME by default (id1)
 	COM_AddGameDirectory (va("%s/"GAMENAME, com_basedir));
-	strcpy (com_gamedir, va("%s/"GAMENAME, com_basedir));
+	q_strlcpy (com_gamedir, va("%s/"GAMENAME, com_basedir), sizeof(com_gamedir));
 
 #if defined(USE_QS_CONBACK)
 	if (!fitzmode)
@@ -1965,6 +1973,8 @@ void COM_InitFilesystem (void) //johnfitz -- modified based on topaz's tutorial
 		com_modified = true;
 		COM_AddGameDirectory (va("%s/%s", com_basedir, com_argv[i + 1]));
 	}
+
+	COM_CheckRegistered ();
 }
 
 
@@ -2106,3 +2116,19 @@ int FS_ferror(fshandle_t *fh)
 	return ferror(fh->file);
 }
 
+char *FS_fgets(char *s, int size, fshandle_t *fh)
+{
+	char *ret;
+
+	if (FS_feof(fh))
+		return NULL;
+
+	if (size > (fh->length - fh->pos) + 1)
+		size = (fh->length - fh->pos) + 1;
+
+	ret = fgets(s, size, fh->file);
+	fh->pos = ftell(fh->file) - fh->start;
+
+	return ret;
+}
+
