@@ -47,8 +47,8 @@ int			con_current;		// where next message will be printed
 int			con_x;				// offset in current line for next print
 char		*con_text = NULL;
 
-cvar_t		con_notifytime = {"con_notifytime","3"};		//seconds
-cvar_t		con_logcenterprint = {"con_logcenterprint", "1"}; //johnfitz
+cvar_t		con_notifytime = {"con_notifytime","3",CVAR_NONE};	//seconds
+cvar_t		con_logcenterprint = {"con_logcenterprint", "1", CVAR_NONE}; //johnfitz
 
 char		con_lastcenterstring[1024]; //johnfitz
 
@@ -80,7 +80,7 @@ const char *Con_Quakebar (int len)
 	static char bar[42];
 	int i;
 
-	len = q_min(len, sizeof(bar) - 2);
+	len = q_min(len, (int)sizeof(bar) - 2);
 	len = q_min(len, con_linewidth);
 
 	bar[0] = '\35';
@@ -162,7 +162,7 @@ void Con_Dump_f (void)
 #if 1
 	//johnfitz -- there is a security risk in writing files with an arbitrary filename. so,
 	//until stuffcmd is crippled to alleviate this risk, just force the default filename.
-	sprintf (name, "%s/condump.txt", com_gamedir);
+	q_snprintf (name, sizeof(name), "%s/condump.txt", com_gamedir);
 #else
 	if (Cmd_Argc() > 2)
 	{
@@ -177,11 +177,11 @@ void Con_Dump_f (void)
 			Con_Printf ("Relative pathnames are not allowed.\n");
 			return;
 		}
-		sprintf (name, "%s/%s", com_gamedir, Cmd_Argv(1));
-		COM_DefaultExtension (name, ".txt");
+		q_snprintf (name, sizeof(name), "%s/%s", com_gamedir, Cmd_Argv(1));
+		COM_DefaultExtension (name, ".txt", sizeof(name));
 	}
 	else
-		sprintf (name, "%s/condump.txt", com_gamedir);
+		q_snprintf (name, sizeof(name), "%s/condump.txt", com_gamedir);
 #endif
 
 	COM_CreatePath (name);
@@ -329,9 +329,12 @@ Con_Init
 */
 void Con_Init (void)
 {
+	int i;
+
 	//johnfitz -- user settable console buffer size
-	if (COM_CheckParm("-consize"))
-		con_buffersize = q_max(CON_MINSIZE,Q_atoi(com_argv[COM_CheckParm("-consize")+1])*1024);
+	i = COM_CheckParm("-consize");
+	if (i && i < com_argc-1)
+		con_buffersize = q_max(CON_MINSIZE,Q_atoi(com_argv[i+1])*1024);
 	else
 		con_buffersize = CON_TEXTSIZE;
 	//johnfitz
@@ -352,8 +355,8 @@ void Con_Init (void)
 //
 // register our commands
 //
-	Cvar_RegisterVariable (&con_notifytime, NULL);
-	Cvar_RegisterVariable (&con_logcenterprint, NULL); //johnfitz
+	Cvar_RegisterVariable (&con_notifytime);
+	Cvar_RegisterVariable (&con_logcenterprint); //johnfitz
 
 	Cmd_AddCommand ("toggleconsole", Con_ToggleConsole_f);
 	Cmd_AddCommand ("messagemode", Con_MessageMode_f);
@@ -399,6 +402,7 @@ void Con_Print (const char *txt)
 	int		c, l;
 	static int	cr;
 	int		mask;
+	qboolean	boundary;
 
 	//con_backscroll = 0; //johnfitz -- better console scrolling
 
@@ -417,17 +421,27 @@ void Con_Print (const char *txt)
 	else
 		mask = 0;
 
+	boundary = true;
 
 	while ( (c = *txt) )
 	{
-	// count word length
-		for (l=0 ; l< con_linewidth ; l++)
-			if ( txt[l] <= ' ')
-				break;
+		if (c <= ' ')
+		{
+			boundary = true;
+		}
+		else if (boundary)
+		{
+			// count word length
+			for (l = 0; l < con_linewidth; l++)
+				if (txt[l] <= ' ')
+					break;
 
-	// word wrap
-		if (l != con_linewidth && (con_x + l > con_linewidth) )
-			con_x = 0;
+			// word wrap
+			if (l != con_linewidth && (con_x + l > con_linewidth))
+				con_x = 0;
+
+			boundary = false;
+		}
 
 		txt++;
 
@@ -884,7 +898,8 @@ void BuildTabList (const char *partial)
 	bash_partial[0] = 0;
 	bash_singlematch = 1;
 
-	for (cvar=cvar_vars ; cvar ; cvar=cvar->next)
+	cvar = Cvar_FindVarAfter ("", CVAR_NONE);
+	for ( ; cvar ; cvar=cvar->next)
 		if (!Q_strncmp (partial, cvar->name, len))
 			AddToTabList (cvar->name, "cvar");
 
@@ -1124,30 +1139,27 @@ void Con_DrawInput (void)
 	extern	qpic_t *pic_ovr, *pic_ins; //johnfitz -- new cursor handling
 	extern	double key_blinktime;
 	extern	int key_insert;
-	int	i, len;
-	char	c[MAXCMDLINE], *text;
+	int	i, ofs;
 
 	if (key_dest != key_console && !con_forcedup)
 		return;		// don't draw anything
 
-	text = strcpy(c, key_lines[edit_line]);
-
-// pad with one space so we can draw one past the string (in case the cursor is there)
-	len = strlen(key_lines[edit_line]);
-	text[len] = ' ';
-	text[len+1] = 0;
-
 // prestep if horizontally scrolling
 	if (key_linepos >= con_linewidth)
-		text += 1 + key_linepos - con_linewidth;
+		ofs = 1 + key_linepos - con_linewidth;
+	else
+		ofs = 0;
 
 // draw input string
-	for (i=0; i <= strlen(text) - 1; i++) //only write enough letters to go from *text to cursor
-		Draw_Character ((i+1)<<3, vid.conheight - 16, text[i]);
+	for (i = 0; key_lines[edit_line][i+ofs] && i < con_linewidth; i++)
+		Draw_Character ((i+1)<<3, vid.conheight - 16, key_lines[edit_line][i+ofs]);
 
 // johnfitz -- new cursor handling
 	if (!((int)((realtime-key_blinktime)*con_cursorspeed) & 1))
-		Draw_Pic ((key_linepos+1)<<3, vid.conheight - 16, key_insert ? pic_ins : pic_ovr);
+	{
+		i = key_linepos - ofs;
+		Draw_Pic ((i+1)<<3, vid.conheight - 16, key_insert ? pic_ins : pic_ovr);
+	}
 }
 
 /*
@@ -1160,9 +1172,9 @@ The typing input line at the bottom should only be drawn if typing is allowed
 */
 void Con_DrawConsole (int lines, qboolean drawinput)
 {
-	int				i, x, y, j, sb, rows;
-	char			ver[32];
-	char			*text;
+	int	i, x, y, j, sb, rows;
+	char	ver[32];
+	char	*text;
 
 	if (lines <= 0)
 		return;
@@ -1174,29 +1186,29 @@ void Con_DrawConsole (int lines, qboolean drawinput)
 	Draw_ConsoleBackground ();
 
 // draw the buffer text
-	rows = (con_vislines+7)/8;
+	rows = (con_vislines +7)/8;
 	y = vid.conheight - rows*8;
 	rows -= 2; //for input and version lines
 	sb = (con_backscroll) ? 2 : 0;
 
-	for (i = con_current - rows + 1 ; i <= con_current - sb ; i++, y+=8)
+	for (i = con_current - rows + 1; i <= con_current - sb; i++, y += 8)
 	{
 		j = i - con_backscroll;
-		if (j<0)
+		if (j < 0)
 			j = 0;
 		text = con_text + (j % con_totallines)*con_linewidth;
 
-		for (x=0 ; x<con_linewidth ; x++)
-			Draw_Character ( (x+1)<<3, y, text[x]);
+		for (x = 0; x < con_linewidth; x++)
+			Draw_Character ( (x + 1)<<3, y, text[x]);
 	}
 
 // draw scrollback arrows
 	if (con_backscroll)
 	{
-		y+=8; // blank line
-		for (x=0 ; x<con_linewidth ; x+=4)
-			Draw_Character ((x+1)<<3, y, '^');
-		y+=8;
+		y += 8; // blank line
+		for (x = 0; x < con_linewidth; x += 4)
+			Draw_Character ((x + 1)<<3, y, '^');
+		y += 8;
 	}
 
 // draw the input prompt, user text, and cursor
@@ -1204,10 +1216,10 @@ void Con_DrawConsole (int lines, qboolean drawinput)
 		Con_DrawInput ();
 
 //draw version number in bottom right
-	y+=8;
+	y += 8;
 	sprintf (ver, "QuakeSpasm %1.2f.%d", (float)FITZQUAKE_VERSION, QUAKESPASM_VER_PATCH);
-	for (x=0; x<strlen(ver); x++)
-		Draw_Character ((con_linewidth-strlen(ver)+x+2)<<3, y, ver[x] /*+ 128*/);
+	for (x = 0; x < (int)strlen(ver); x++)
+		Draw_Character ((con_linewidth - strlen(ver) + x + 2)<<3, y, ver[x] /*+ 128*/);
 }
 
 
@@ -1232,10 +1244,10 @@ void Con_NotifyBox (const char *text)
 
 	do
 	{
-		t1 = Sys_FloatTime ();
+		t1 = Sys_DoubleTime ();
 		SCR_UpdateScreen ();
 		Sys_SendKeyEvents ();
-		t2 = Sys_FloatTime ();
+		t2 = Sys_DoubleTime ();
 		realtime += t2-t1;		// make the cursor blink
 	} while (key_count < 0);
 
@@ -1258,9 +1270,9 @@ void LOG_Init (quakeparms_t *parms)
 	strftime (session, sizeof(session), "%m/%d/%Y %H:%M:%S", localtime(&inittime));
 	q_snprintf (logfilename, sizeof(logfilename), "%s/qconsole.log", parms->basedir);
 
-	unlink (logfilename);
+//	unlink (logfilename);
 
-	log_fd = open (logfilename, O_WRONLY | O_CREAT | O_APPEND, 0666);
+	log_fd = open (logfilename, O_WRONLY | O_CREAT | O_TRUNC, 0666);
 	if (log_fd == -1)
 	{
 		fprintf (stderr, "Error: Unable to create log file %s\n", logfilename);
