@@ -26,7 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 //extern unsigned char d_15to8table[65536]; //johnfitz -- never used
 
-cvar_t		scr_conalpha = {"scr_conalpha", "0.5",true}; //johnfitz
+cvar_t		scr_conalpha = {"scr_conalpha", "0.5", CVAR_ARCHIVE}; //johnfitz
 
 qpic_t		*draw_disc;
 qpic_t		*draw_backtile;
@@ -246,7 +246,7 @@ qpic_t *Draw_PicFromWad (const char *name)
 	else
 	{
 		char texturename[64]; //johnfitz
-		sprintf (texturename, "%s:%s", WADFILENAME, name); //johnfitz
+		q_snprintf (texturename, sizeof(texturename), "%s:%s", WADFILENAME, name); //johnfitz
 
 		offset = (src_offset_t)p - (src_offset_t)wad_base + sizeof(int)*2; //johnfitz
 
@@ -458,7 +458,7 @@ Draw_Init -- johnfitz -- rewritten
 */
 void Draw_Init (void)
 {
-	Cvar_RegisterVariable (&scr_conalpha, NULL);
+	Cvar_RegisterVariable (&scr_conalpha);
 
 	// clear scrap and allocate gltextures
 	memset(&scrap_allocated, 0, sizeof(scrap_allocated));
@@ -788,7 +788,7 @@ void GL_SetCanvas (canvastype newcanvas)
 		glViewport (glx, gly+glheight-gl_warpimagesize, gl_warpimagesize, gl_warpimagesize);
 		break;
 	case CANVAS_CROSSHAIR: //0,0 is center of viewport
-		s = CLAMP (1.0, scr_crosshaircale.value, 10.0);
+		s = CLAMP (1.0, scr_crosshairscale.value, 10.0);
 		glOrtho (scr_vrect.width/-2/s, scr_vrect.width/2/s, scr_vrect.height/2/s, scr_vrect.height/-2/s, -99999, 99999);
 		glViewport (scr_vrect.x, glheight - scr_vrect.y - scr_vrect.height, scr_vrect.width & ~1, scr_vrect.height & ~1);
 		break;
