@@ -62,47 +62,49 @@ mleaf_t		*r_viewleaf, *r_oldviewleaf;
 int		d_lightstylevalue[256];	// 8.8 fraction of base light value
 
 
-cvar_t	r_norefresh = {"r_norefresh","0"};
-cvar_t	r_drawentities = {"r_drawentities","1"};
-cvar_t	r_drawviewmodel = {"r_drawviewmodel","1"};
-cvar_t	r_speeds = {"r_speeds","0"};
-cvar_t	r_fullbright = {"r_fullbright","0"};
-cvar_t	r_lightmap = {"r_lightmap","0"};
-cvar_t	r_shadows = {"r_shadows","0",true};
-cvar_t	r_wateralpha = {"r_wateralpha","1",true};
-cvar_t	r_dynamic = {"r_dynamic","1",true};
-cvar_t	r_novis = {"r_novis","0",true};
+cvar_t	r_norefresh = {"r_norefresh","0",CVAR_NONE};
+cvar_t	r_drawentities = {"r_drawentities","1",CVAR_NONE};
+cvar_t	r_drawviewmodel = {"r_drawviewmodel","1",CVAR_NONE};
+cvar_t	r_speeds = {"r_speeds","0",CVAR_NONE};
+cvar_t	r_fullbright = {"r_fullbright","0",CVAR_NONE};
+cvar_t	r_lightmap = {"r_lightmap","0",CVAR_NONE};
+cvar_t	r_shadows = {"r_shadows","0",CVAR_ARCHIVE};
+cvar_t	r_wateralpha = {"r_wateralpha","1",CVAR_ARCHIVE};
+cvar_t	r_dynamic = {"r_dynamic","1",CVAR_ARCHIVE};
+cvar_t	r_novis = {"r_novis","0",CVAR_ARCHIVE};
 
-cvar_t	gl_finish = {"gl_finish","0"};
-cvar_t	gl_clear = {"gl_clear","0"};
-cvar_t	gl_cull = {"gl_cull","1"};
-cvar_t	gl_smoothmodels = {"gl_smoothmodels","1"};
-cvar_t	gl_affinemodels = {"gl_affinemodels","0"};
-cvar_t	gl_polyblend = {"gl_polyblend","1"};
-cvar_t	gl_flashblend = {"gl_flashblend","0",true};
-cvar_t	gl_playermip = {"gl_playermip","0"};
-cvar_t	gl_nocolors = {"gl_nocolors","0"};
+cvar_t	gl_finish = {"gl_finish","0",CVAR_NONE};
+cvar_t	gl_clear = {"gl_clear","0",CVAR_NONE};
+cvar_t	gl_cull = {"gl_cull","1",CVAR_NONE};
+cvar_t	gl_smoothmodels = {"gl_smoothmodels","1",CVAR_NONE};
+cvar_t	gl_affinemodels = {"gl_affinemodels","0",CVAR_NONE};
+cvar_t	gl_polyblend = {"gl_polyblend","1",CVAR_NONE};
+cvar_t	gl_flashblend = {"gl_flashblend","0",CVAR_ARCHIVE};
+cvar_t	gl_playermip = {"gl_playermip","0",CVAR_NONE};
+cvar_t	gl_nocolors = {"gl_nocolors","0",CVAR_NONE};
 
 //johnfitz -- new cvars
-cvar_t	r_stereo = {"r_stereo","0"};
-cvar_t	r_stereodepth = {"r_stereodepth","128"};
-cvar_t	r_clearcolor = {"r_clearcolor","2", true};
-cvar_t	r_drawflat = {"r_drawflat","0"};
-cvar_t	r_flatlightstyles = {"r_flatlightstyles", "0"};
-cvar_t	gl_fullbrights = {"gl_fullbrights", "1", true};
-cvar_t	gl_farclip = {"gl_farclip", "16384", true};
-cvar_t	gl_overbright = {"gl_overbright", "1", true};
-cvar_t	gl_overbright_models = {"gl_overbright_models", "1", true};
-cvar_t	r_oldskyleaf = {"r_oldskyleaf", "0"};
-cvar_t	r_drawworld = {"r_drawworld", "1"};
-cvar_t	r_showtris = {"r_showtris", "0"};
-cvar_t	r_showbboxes = {"r_showbboxes", "0"};
-cvar_t	r_lerpmodels = {"r_lerpmodels", "1"};
-cvar_t	r_lerpmove = {"r_lerpmove", "1"};
-cvar_t	r_nolerp_list = {"r_nolerp_list", "progs/flame.mdl,progs/flame2.mdl,progs/braztall.mdl,progs/brazshrt.mdl,progs/longtrch.mdl,progs/flame_pyre.mdl,progs/v_saw.mdl,progs/v_xfist.mdl,progs/h2stuff/newfire.mdl"};
+cvar_t	r_stereo = {"r_stereo","0",CVAR_NONE};
+cvar_t	r_stereodepth = {"r_stereodepth","128",CVAR_NONE};
+cvar_t	r_clearcolor = {"r_clearcolor","2",CVAR_ARCHIVE};
+cvar_t	r_drawflat = {"r_drawflat","0",CVAR_NONE};
+cvar_t	r_flatlightstyles = {"r_flatlightstyles", "0", CVAR_NONE};
+cvar_t	gl_fullbrights = {"gl_fullbrights", "1", CVAR_ARCHIVE};
+cvar_t	gl_farclip = {"gl_farclip", "16384", CVAR_ARCHIVE};
+cvar_t	gl_overbright = {"gl_overbright", "1", CVAR_ARCHIVE};
+cvar_t	gl_overbright_models = {"gl_overbright_models", "1", CVAR_ARCHIVE};
+cvar_t	r_oldskyleaf = {"r_oldskyleaf", "0", CVAR_NONE};
+cvar_t	r_drawworld = {"r_drawworld", "1", CVAR_NONE};
+cvar_t	r_showtris = {"r_showtris", "0", CVAR_NONE};
+cvar_t	r_showbboxes = {"r_showbboxes", "0", CVAR_NONE};
+cvar_t	r_lerpmodels = {"r_lerpmodels", "1", CVAR_NONE};
+cvar_t	r_lerpmove = {"r_lerpmove", "1", CVAR_NONE};
+cvar_t	r_nolerp_list = {"r_nolerp_list", "progs/flame.mdl,progs/flame2.mdl,progs/braztall.mdl,progs/brazshrt.mdl,progs/longtrch.mdl,progs/flame_pyre.mdl,progs/v_saw.mdl,progs/v_xfist.mdl,progs/h2stuff/newfire.mdl", CVAR_NONE};
 extern cvar_t	r_vfog;
 //johnfitz
 
+cvar_t	gl_zfix = {"gl_zfix", "1", CVAR_ARCHIVE}; // QuakeSpasm z-fighting fix
+
 qboolean r_drawflat_cheatsafe, r_fullbright_cheatsafe, r_lightmap_cheatsafe, r_drawworld_cheatsafe; //johnfitz
 
 /*
@@ -363,7 +365,6 @@ R_Clear -- johnfitz -- rewritten and gutted
 */
 void R_Clear (void)
 {
-	extern int gl_stencilbits;
 	unsigned int clearbits;
 
 	clearbits = GL_DEPTH_BUFFER_BIT;
@@ -788,7 +789,7 @@ void R_RenderView (void)
 	if (r_speeds.value)
 	{
 		glFinish ();
-		time1 = Sys_FloatTime ();
+		time1 = Sys_DoubleTime ();
 
 		//johnfitz -- rendering statistics
 		rs_brushpolys = rs_aliaspolys = rs_skypolys = rs_particles = rs_fogpolys = rs_megatexels =
@@ -836,7 +837,7 @@ void R_RenderView (void)
 	//johnfitz
 
 	//johnfitz -- modified r_speeds output
-	time2 = Sys_FloatTime ();
+	time2 = Sys_DoubleTime ();
 	if (r_speeds.value == 2)
 		Con_Printf ("%3i ms  %4i/%4i wpoly %4i/%4i epoly %3i lmap %4i/%4i sky %1.1f mtex\n",
 					(int)((time2-time1)*1000),
