@@ -77,29 +77,27 @@ int			glx, gly, glwidth, glheight;
 float		scr_con_current;
 float		scr_conlines;		// lines of console to display
 
-float		oldscreensize, oldfov, oldsbarscale, oldsbaralpha; //johnfitz -- added oldsbarscale and oldsbaralpha
-
 //johnfitz -- new cvars
-cvar_t		scr_menuscale = {"scr_menuscale", "1", true};
-cvar_t		scr_sbarscale = {"scr_sbarscale", "1", true};
-cvar_t		scr_sbaralpha = {"scr_sbaralpha", "0.95", true};
-cvar_t		scr_conwidth = {"scr_conwidth", "0", true};
-cvar_t		scr_conscale = {"scr_conscale", "1", true};
-cvar_t		scr_scale = {"scr_scale", "1", true};
-cvar_t		scr_crosshaircale = {"scr_crosshaircale", "1", true};
-cvar_t		scr_showfps = {"scr_showfps", "0"};
-cvar_t		scr_clock = {"scr_clock", "0"};
+cvar_t		scr_menuscale = {"scr_menuscale", "1", CVAR_ARCHIVE};
+cvar_t		scr_sbarscale = {"scr_sbarscale", "1", CVAR_ARCHIVE};
+cvar_t		scr_sbaralpha = {"scr_sbaralpha", "0.95", CVAR_ARCHIVE};
+cvar_t		scr_conwidth = {"scr_conwidth", "0", CVAR_ARCHIVE};
+cvar_t		scr_conscale = {"scr_conscale", "1", CVAR_ARCHIVE};
+cvar_t		scr_scale = {"scr_scale", "1", CVAR_ARCHIVE};
+cvar_t		scr_crosshairscale = {"scr_crosshairscale", "1", CVAR_ARCHIVE};
+cvar_t		scr_showfps = {"scr_showfps", "0", CVAR_NONE};
+cvar_t		scr_clock = {"scr_clock", "0", CVAR_NONE};
 //johnfitz
 
-cvar_t		scr_viewsize = {"viewsize","100", true};
-cvar_t		scr_fov = {"fov","90"};	// 10 - 170
-cvar_t		scr_conspeed = {"scr_conspeed","500",true};
-cvar_t		scr_centertime = {"scr_centertime","2"};
-cvar_t		scr_showram = {"showram","1"};
-cvar_t		scr_showturtle = {"showturtle","0"};
-cvar_t		scr_showpause = {"showpause","1"};
-cvar_t		scr_printspeed = {"scr_printspeed","8"};
-cvar_t		gl_triplebuffer = {"gl_triplebuffer", "1", true };
+cvar_t		scr_viewsize = {"viewsize","100", CVAR_ARCHIVE};
+cvar_t		scr_fov = {"fov","90",CVAR_NONE};	// 10 - 170
+cvar_t		scr_conspeed = {"scr_conspeed","500",CVAR_ARCHIVE};
+cvar_t		scr_centertime = {"scr_centertime","2",CVAR_NONE};
+cvar_t		scr_showram = {"showram","1",CVAR_NONE};
+cvar_t		scr_showturtle = {"showturtle","0",CVAR_NONE};
+cvar_t		scr_showpause = {"showpause","1",CVAR_NONE};
+cvar_t		scr_printspeed = {"scr_printspeed","8",CVAR_NONE};
+cvar_t		gl_triplebuffer = {"gl_triplebuffer", "1", CVAR_ARCHIVE};
 
 extern	cvar_t	crosshair;
 
@@ -118,8 +116,6 @@ qboolean	scr_disabled_for_loading;
 qboolean	scr_drawloading;
 float		scr_disabled_time;
 
-qboolean	block_drawing;
-
 int	scr_tileclear_updates = 0; //johnfitz
 
 void SCR_ScreenShot_f (void);
@@ -155,6 +151,7 @@ void SCR_CenterPrint (const char *str) //update centerprint data
 
 // count the number of lines for centering
 	scr_center_lines = 1;
+	str = scr_centerstring;
 	while (*str)
 	{
 		if (*str == '\n')
@@ -261,8 +258,6 @@ static void SCR_CalcRefdef (void)
 {
 	float		size, scale; //johnfitz -- scale
 
-	vid.recalc_refdef = 0;
-
 // force the status bar to redraw
 	Sbar_Changed ();
 
@@ -270,15 +265,17 @@ static void SCR_CalcRefdef (void)
 
 // bound viewsize
 	if (scr_viewsize.value < 30)
-		Cvar_Set ("viewsize","30");
+		Cvar_SetQuick (&scr_viewsize, "30");
 	if (scr_viewsize.value > 120)
-		Cvar_Set ("viewsize","120");
+		Cvar_SetQuick (&scr_viewsize, "120");
 
 // bound fov
 	if (scr_fov.value < 10)
-		Cvar_Set ("fov","10");
+		Cvar_SetQuick (&scr_fov, "10");
 	if (scr_fov.value > 170)
-		Cvar_Set ("fov","170");
+		Cvar_SetQuick (&scr_fov, "170");
+
+	vid.recalc_refdef = 0;
 
 	//johnfitz -- rewrote this section
 	size = scr_viewsize.value;
@@ -317,8 +314,7 @@ Keybinding command
 */
 void SCR_SizeUp_f (void)
 {
-	Cvar_SetValue ("viewsize",scr_viewsize.value+10);
-	vid.recalc_refdef = 1;
+	Cvar_SetValueQuick (&scr_viewsize, scr_viewsize.value+10);
 }
 
 
@@ -331,7 +327,11 @@ Keybinding command
 */
 void SCR_SizeDown_f (void)
 {
-	Cvar_SetValue ("viewsize",scr_viewsize.value-10);
+	Cvar_SetValueQuick (&scr_viewsize, scr_viewsize.value-10);
+}
+
+static void SCR_Callback_refdef (cvar_t *var)
+{
 	vid.recalc_refdef = 1;
 }
 
@@ -340,8 +340,9 @@ void SCR_SizeDown_f (void)
 SCR_Conwidth_f -- johnfitz -- called when scr_conwidth or scr_conscale changes
 ==================
 */
-void SCR_Conwidth_f (void)
+void SCR_Conwidth_f (cvar_t *var)
 {
+	vid.recalc_refdef = 1;
 	vid.conwidth = (scr_conwidth.value > 0) ? (int)scr_conwidth.value : (scr_conscale.value > 0) ? (int)(vid.width/scr_conscale.value) : vid.width;
 	vid.conwidth = CLAMP (320, vid.conwidth, vid.width);
 	vid.conwidth &= 0xFFFFFFF8;
@@ -369,26 +370,29 @@ SCR_Init
 void SCR_Init (void)
 {
 	//johnfitz -- new cvars
-	Cvar_RegisterVariable (&scr_menuscale, NULL);
-	Cvar_RegisterVariable (&scr_sbarscale, NULL);
-	Cvar_RegisterVariable (&scr_sbaralpha, NULL);
-	Cvar_RegisterVariable (&scr_conwidth, &SCR_Conwidth_f);
-	Cvar_RegisterVariable (&scr_conscale, &SCR_Conwidth_f);
-	Cvar_RegisterVariable (&scr_scale, NULL);
-	Cvar_RegisterVariable (&scr_crosshaircale, NULL);
-	Cvar_RegisterVariable (&scr_showfps, NULL);
-	Cvar_RegisterVariable (&scr_clock, NULL);
+	Cvar_RegisterVariable (&scr_menuscale);
+	Cvar_RegisterVariable (&scr_sbarscale);
+	Cvar_RegisterVariable (&scr_sbaralpha);
+	Cvar_SetCallback (&scr_conwidth, &SCR_Conwidth_f);
+	Cvar_SetCallback (&scr_conscale, &SCR_Conwidth_f);
+	Cvar_RegisterVariable (&scr_conwidth);
+	Cvar_RegisterVariable (&scr_conscale);
+	Cvar_RegisterVariable (&scr_scale);
+	Cvar_RegisterVariable (&scr_crosshairscale);
+	Cvar_RegisterVariable (&scr_showfps);
+	Cvar_RegisterVariable (&scr_clock);
 	//johnfitz
-
-	Cvar_RegisterVariable (&scr_fov, NULL);
-	Cvar_RegisterVariable (&scr_viewsize, NULL);
-	Cvar_RegisterVariable (&scr_conspeed, NULL);
-	Cvar_RegisterVariable (&scr_showram, NULL);
-	Cvar_RegisterVariable (&scr_showturtle, NULL);
-	Cvar_RegisterVariable (&scr_showpause, NULL);
-	Cvar_RegisterVariable (&scr_centertime, NULL);
-	Cvar_RegisterVariable (&scr_printspeed, NULL);
-	Cvar_RegisterVariable (&gl_triplebuffer, NULL);
+	Cvar_SetCallback (&scr_fov, SCR_Callback_refdef);
+	Cvar_SetCallback (&scr_viewsize, SCR_Callback_refdef);
+	Cvar_RegisterVariable (&scr_fov);
+	Cvar_RegisterVariable (&scr_viewsize);
+	Cvar_RegisterVariable (&scr_conspeed);
+	Cvar_RegisterVariable (&scr_showram);
+	Cvar_RegisterVariable (&scr_showturtle);
+	Cvar_RegisterVariable (&scr_showpause);
+	Cvar_RegisterVariable (&scr_centertime);
+	Cvar_RegisterVariable (&scr_printspeed);
+	Cvar_RegisterVariable (&gl_triplebuffer);
 
 	Cmd_AddCommand ("screenshot",SCR_ScreenShot_f);
 	Cmd_AddCommand ("sizeup",SCR_SizeUp_f);
@@ -408,37 +412,39 @@ SCR_DrawFPS -- johnfitz
 */
 void SCR_DrawFPS (void)
 {
-	static double	oldtime = 0, fps = 0;
-	static int		oldframecount = 0;
-	double			time;
-	char			str[12];
-	int				x, y, frames;
+	static double	oldtime = 0;
+	static double	lastfps = 0;
+	static int	oldframecount = 0;
+	double	elapsed_time;
+	int	frames;
 
-	time = realtime - oldtime;
+	elapsed_time = realtime - oldtime;
 	frames = r_framecount - oldframecount;
 
-	if (time < 0 || frames < 0)
+	if (elapsed_time < 0 || frames < 0)
 	{
 		oldtime = realtime;
 		oldframecount = r_framecount;
 		return;
 	}
-
-	if (time > 0.75) //update value every 3/4 second
+	// update value every 3/4 second
+	if (elapsed_time > 0.75)
 	{
-		fps = frames / time;
+		lastfps = frames / elapsed_time;
 		oldtime = realtime;
 		oldframecount = r_framecount;
 	}
 
-	if (scr_showfps.value) //draw it
+	if (scr_showfps.value)
 	{
-		sprintf (str, "%4.0f fps", fps);
-		x = 320 - (strlen(str)<<3);
+		char	st[16];
+		int	x, y;
+		sprintf (st, "%4.0f fps", lastfps);
+		x = 320 - (strlen(st)<<3);
 		y = 200 - 8;
 		if (scr_clock.value) y -= 8; //make room for clock
 		GL_SetCanvas (CANVAS_BOTTOMRIGHT);
-		Draw_String (x, y, str);
+		Draw_String (x, y, st);
 		scr_tileclear_updates = 0;
 	}
 
@@ -451,7 +457,7 @@ SCR_DrawClock -- johnfitz
 */
 void SCR_DrawClock (void)
 {
-	char	str[9];
+	char	str[12];
 
 	if (scr_clock.value == 1)
 	{
@@ -738,8 +744,8 @@ void SCR_ScreenShot_f (void)
 // find a file name to save it to
 	for (i=0; i<10000; i++)
 	{
-		sprintf (tganame, "spasm%04i.tga", i);	// "fitz%04i.tga"
-		sprintf (checkname, "%s/%s", com_gamedir, tganame);
+		q_snprintf (tganame, sizeof(tganame), "spasm%04i.tga", i);	// "fitz%04i.tga"
+		q_snprintf (checkname, sizeof(checkname), "%s/%s", com_gamedir, tganame);
 		if (Sys_FileTime(checkname) == -1)
 			break;	// file doesn't exist
 	}
@@ -870,19 +876,24 @@ int SCR_ModalMessage (const char *text, float timeout) //johnfitz -- timeout
 
 	S_ClearBuffer ();		// so dma doesn't loop current sound
 
-	time1 = Sys_FloatTime () + timeout; //johnfitz -- timeout
+	time1 = Sys_DoubleTime () + timeout; //johnfitz -- timeout
 	time2 = 0.0f; //johnfitz -- timeout
 
 	do
 	{
 		key_count = -1;		// wait for a key down and up
 		Sys_SendKeyEvents ();
-		if (timeout) time2 = Sys_FloatTime (); //johnfitz -- zero timeout means wait forever.
+		if (timeout) time2 = Sys_DoubleTime (); //johnfitz -- zero timeout means wait forever.
+		Sys_Sleep(16);
 	} while (key_lastpress != 'y' &&
 			 key_lastpress != 'n' &&
 			 key_lastpress != K_ESCAPE &&
 			 time2 <= time1);
 
+	// make sure we don't ignore the next keypress
+	if (key_count < 0)
+		key_count = 0;
+
 //	SCR_UpdateScreen (); //johnfitz -- commented out
 
 	//johnfitz -- timeout
@@ -954,10 +965,7 @@ needs almost the entire 256k of stack space!
 */
 void SCR_UpdateScreen (void)
 {
-	if (block_drawing)
-		return;
-
-	vid.numpages = 2 + (gl_triplebuffer.value ? 1 : 0); //johnfitz -- in case gl_triplebuffer is not 0 or 1
+	vid.numpages = (gl_triplebuffer.value) ? 3 : 2;
 
 	if (scr_disabled_for_loading)
 	{
@@ -979,33 +987,6 @@ void SCR_UpdateScreen (void)
 	//
 	// determine size of refresh window
 	//
-
-	if (oldfov != scr_fov.value)
-	{
-		oldfov = scr_fov.value;
-		vid.recalc_refdef = true;
-	}
-
-	if (oldscreensize != scr_viewsize.value)
-	{
-		oldscreensize = scr_viewsize.value;
-		vid.recalc_refdef = true;
-	}
-
-	//johnfitz -- added oldsbarscale and oldsbaralpha
-	if (oldsbarscale != scr_sbarscale.value)
-	{
-		oldsbarscale = scr_sbarscale.value;
-		vid.recalc_refdef = true;
-	}
-
-	if (oldsbaralpha != scr_sbaralpha.value)
-	{
-		oldsbaralpha = scr_sbaralpha.value;
-		vid.recalc_refdef = true;
-	}
-	//johnfitz
-
 	if (vid.recalc_refdef)
 		SCR_CalcRefdef ();
 
