@@ -23,19 +23,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "quakedef.h"
 
-extern qboolean	gl_anisotropy_able;
-
-cvar_t		gl_texture_anisotropy = {"gl_texture_anisotropy", "1", true};
-cvar_t		gl_max_size = {"gl_max_size", "0"};
-cvar_t		gl_picmip = {"gl_picmip", "0"};
-GLint			gl_hardware_maxsize;
 const int	gl_solid_format = 3;
 const int	gl_alpha_format = 4;
 
+static cvar_t	gl_texturemode = {"gl_texturemode", "", CVAR_ARCHIVE};
+static cvar_t	gl_texture_anisotropy = {"gl_texture_anisotropy", "1", CVAR_ARCHIVE};
+static cvar_t	gl_max_size = {"gl_max_size", "0", CVAR_NONE};
+static cvar_t	gl_picmip = {"gl_picmip", "0", CVAR_NONE};
+static GLint	gl_hardware_maxsize;
+
 #define	MAX_GLTEXTURES	2048
-gltexture_t	*active_gltextures, *free_gltextures;
-gltexture_t	*notexture, *nulltexture;
-int numgltextures;
+static int numgltextures;
+static gltexture_t	*active_gltextures, *free_gltextures;
+gltexture_t		*notexture, *nulltexture;
 
 unsigned int d_8to24table[256];
 unsigned int d_8to24table_fbright[256];
@@ -58,28 +58,28 @@ typedef struct
 	int	minfilter;
 	const char  *name;
 } glmode_t;
-glmode_t modes[] = {
-	{GL_NEAREST, GL_NEAREST,				"GL_NEAREST"},
+static glmode_t glmodes[] = {
+	{GL_NEAREST, GL_NEAREST,		"GL_NEAREST"},
 	{GL_NEAREST, GL_NEAREST_MIPMAP_NEAREST,	"GL_NEAREST_MIPMAP_NEAREST"},
 	{GL_NEAREST, GL_NEAREST_MIPMAP_LINEAR,	"GL_NEAREST_MIPMAP_LINEAR"},
-	{GL_LINEAR,  GL_LINEAR,					"GL_LINEAR"},
+	{GL_LINEAR,  GL_LINEAR,			"GL_LINEAR"},
 	{GL_LINEAR,  GL_LINEAR_MIPMAP_NEAREST,	"GL_LINEAR_MIPMAP_NEAREST"},
 	{GL_LINEAR,  GL_LINEAR_MIPMAP_LINEAR,	"GL_LINEAR_MIPMAP_LINEAR"},
 };
-#define NUM_GLMODES 6
-int gl_texturemode = 5; // bilinear
+#define NUM_GLMODES (int)(sizeof(glmodes)/sizeof(glmodes[0]))
+static int glmode_idx = NUM_GLMODES - 1; /* trilinear */
 
 /*
 ===============
 TexMgr_DescribeTextureModes_f -- report available texturemodes
 ===============
 */
-void TexMgr_DescribeTextureModes_f (void)
+static void TexMgr_DescribeTextureModes_f (void)
 {
 	int i;
 
-	for (i=0; i<NUM_GLMODES; i++)
-		Con_SafePrintf ("   %2i: %s\n", i + 1, modes[i].name);
+	for (i = 0; i < NUM_GLMODES; i++)
+		Con_SafePrintf ("   %2i: %s\n", i + 1, glmodes[i].name);
 
 	Con_Printf ("%i modes\n", i);
 }
@@ -89,7 +89,7 @@ void TexMgr_DescribeTextureModes_f (void)
 TexMgr_SetFilterModes
 ===============
 */
-void TexMgr_SetFilterModes (gltexture_t *glt)
+static void TexMgr_SetFilterModes (gltexture_t *glt)
 {
 	GL_Bind (glt);
 
@@ -105,91 +105,92 @@ void TexMgr_SetFilterModes (gltexture_t *glt)
 	}
 	else if (glt->flags & TEXPREF_MIPMAP)
 	{
-		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, modes[gl_texturemode].magfilter);
-		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, modes[gl_texturemode].minfilter);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, glmodes[glmode_idx].magfilter);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, glmodes[glmode_idx].minfilter);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, gl_texture_anisotropy.value);
 	}
 	else
 	{
-		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, modes[gl_texturemode].magfilter);
-		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, modes[gl_texturemode].magfilter);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, glmodes[glmode_idx].magfilter);
+		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, glmodes[glmode_idx].magfilter);
 	}
-
-	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, gl_texture_anisotropy.value);
 }
 
 /*
 ===============
-TexMgr_TextureMode_f
+TexMgr_TextureMode_f -- called when gl_texturemode changes
 ===============
 */
-void TexMgr_TextureMode_f (void)
+static void TexMgr_TextureMode_f (cvar_t *var)
 {
 	gltexture_t	*glt;
-	const char	*arg;
 	int i;
 
-	switch (Cmd_Argc())
+	for (i = 0; i < NUM_GLMODES; i++)
 	{
-	case 1:
-		Con_Printf ("\"gl_texturemode\" is \"%s\"\n", modes[gl_texturemode].name);
-		break;
-	case 2:
-		arg = Cmd_Argv(1);
-		if (arg[0] == 'G' || arg[0] == 'g')
+		if (!Q_strcmp (glmodes[i].name, gl_texturemode.string))
 		{
-			for (i=0; i<NUM_GLMODES; i++)
-				if (!Q_strcasecmp (modes[i].name, arg))
-				{
-					gl_texturemode = i;
-					goto stuff;
-				}
-			Con_Printf ("\"%s\" is not a valid texturemode\n", arg);
+			if (glmode_idx != i)
+			{
+				glmode_idx = i;
+				for (glt = active_gltextures; glt; glt = glt->next)
+					TexMgr_SetFilterModes (glt);
+				Sbar_Changed (); //sbar graphics need to be redrawn with new filter mode
+				//FIXME: warpimages need to be redrawn, too.
+			}
 			return;
 		}
-		else if (arg[0] >= '0' && arg[0] <= '9')
-		{
-			i = atoi(arg);
-			if (i > NUM_GLMODES || i < 1)
-			{
-				Con_Printf ("\"%s\" is not a valid texturemode\n", arg);
-				return;
-			}
-			gl_texturemode = i - 1;
-		}
-		else
-			Con_Printf ("\"%s\" is not a valid texturemode\n", arg);
-
-stuff:
-		for (glt=active_gltextures; glt; glt=glt->next)
-			TexMgr_SetFilterModes (glt);
-
-		Sbar_Changed (); //sbar graphics need to be redrawn with new filter mode
-
-		//FIXME: warpimages need to be redrawn, too.
-
-		break;
-	default:
-		Con_SafePrintf ("usage: gl_texturemode <mode>\n");
-		break;
 	}
+
+	for (i = 0; i < NUM_GLMODES; i++)
+	{
+		if (!Q_strcasecmp (glmodes[i].name, gl_texturemode.string))
+		{
+			Cvar_SetQuick (&gl_texturemode, glmodes[i].name);
+			return;
+		}
+	}
+
+	i = atoi(gl_texturemode.string);
+	if (i >= 1 && i <= NUM_GLMODES)
+	{
+		Cvar_SetQuick (&gl_texturemode, glmodes[i-1].name);
+		return;
+	}
+
+	Con_Printf ("\"%s\" is not a valid texturemode\n", gl_texturemode.string);
+	Cvar_SetQuick (&gl_texturemode, glmodes[glmode_idx].name);
 }
 
 /*
 ===============
 TexMgr_Anisotropy_f -- called when gl_texture_anisotropy changes
-
-FIXME: this is getting called twice (becuase of the recursive Cvar_SetValue call)
 ===============
 */
-void TexMgr_Anisotropy_f (void)
+static void TexMgr_Anisotropy_f (cvar_t *var)
 {
-	extern float gl_max_anisotropy;
-	gltexture_t	*glt;
-
-	Cvar_SetValue ("gl_texture_anisotropy", CLAMP (1.0f, gl_texture_anisotropy.value, gl_max_anisotropy));
-
-	for (glt=active_gltextures; glt; glt=glt->next)
-		TexMgr_SetFilterModes (glt);
+	if (gl_texture_anisotropy.value < 1)
+	{
+		Cvar_SetQuick (&gl_texture_anisotropy, "1");
+	}
+	else if (gl_texture_anisotropy.value > gl_max_anisotropy)
+	{
+		Cvar_SetValueQuick (&gl_texture_anisotropy, gl_max_anisotropy);
+	}
+	else
+	{
+		gltexture_t	*glt;
+		for (glt = active_gltextures; glt; glt = glt->next)
+		{
+		/*  TexMgr_SetFilterModes (glt);*/
+		    if (glt->flags & TEXPREF_MIPMAP) {
+			GL_Bind (glt);
+			glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, glmodes[glmode_idx].magfilter);
+			glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, glmodes[glmode_idx].minfilter);
+			glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, gl_texture_anisotropy.value);
+		    }
+		}
+	}
 }
 
 /*
@@ -197,14 +198,13 @@ void TexMgr_Anisotropy_f (void)
 TexMgr_Imagelist_f -- report loaded textures
 ===============
 */
-void TexMgr_Imagelist_f (void)
+static void TexMgr_Imagelist_f (void)
 {
 	float mb;
 	float texels = 0;
 	gltexture_t	*glt;
-	extern cvar_t vid_bpp;
 
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
 	{
 		Con_SafePrintf ("   %4i x%4i %s\n", glt->width, glt->height, glt->name);
 		if (glt->flags & TEXPREF_MIPMAP)
@@ -213,7 +213,7 @@ void TexMgr_Imagelist_f (void)
 			texels += (glt->width * glt->height);
 	}
 
-	mb = texels * (vid_bpp.value / 8.0f) / 0x100000;
+	mb = texels * (Cvar_VariableValue("vid_bpp") / 8.0f) / 0x100000;
 	Con_Printf ("%i textures %i pixels %1.1f megabytes\n", numgltextures, (int)texels, mb);
 }
 
@@ -222,7 +222,7 @@ void TexMgr_Imagelist_f (void)
 TexMgr_Imagedump_f -- dump all current textures to TGA files
 ===============
 */
-void TexMgr_Imagedump_f (void)
+static void TexMgr_Imagedump_f (void)
 {
 	char tganame[MAX_OSPATH], tempname[MAX_OSPATH], dirname[MAX_OSPATH];
 	gltexture_t	*glt;
@@ -230,17 +230,17 @@ void TexMgr_Imagedump_f (void)
 	char *c;
 
 	//create directory
-	sprintf(dirname, "%s/imagedump", com_gamedir);
+	q_snprintf(dirname, sizeof(dirname), "%s/imagedump", com_gamedir);
 	Sys_mkdir (dirname);
 
 	//loop through textures
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
 	{
-		Q_strcpy(tempname, glt->name);
+		q_strlcpy (tempname, glt->name, sizeof(tempname));
 		while ( (c = strchr(tempname, ':')) ) *c = '_';
 		while ( (c = strchr(tempname, '/')) ) *c = '_';
 		while ( (c = strchr(tempname, '*')) ) *c = '_';
-		sprintf(tganame, "imagedump/%s.tga", tempname);
+		q_snprintf(tganame, sizeof(tganame), "imagedump/%s.tga", tempname);
 
 		GL_Bind (glt);
 		if (glt->flags & TEXPREF_ALPHA)
@@ -271,9 +271,9 @@ float TexMgr_FrameUsage (void)
 	float mb;
 	float texels = 0;
 	gltexture_t	*glt;
-	extern cvar_t vid_bpp;
 
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
+	{
 		if (glt->visframe == r_framecount)
 		{
 			if (glt->flags & TEXPREF_MIPMAP)
@@ -281,8 +281,9 @@ float TexMgr_FrameUsage (void)
 			else
 				texels += (glt->width * glt->height);
 		}
+	}
 
-	mb = texels * (vid_bpp.value / 8.0f) / 0x100000;
+	mb = texels * (Cvar_VariableValue("vid_bpp") / 8.0f) / 0x100000;
 	return mb;
 }
 
@@ -305,9 +306,11 @@ gltexture_t *TexMgr_FindTexture (model_t *owner, const char *name)
 
 	if (name)
 	{
-		for (glt=active_gltextures; glt; glt=glt->next)
+		for (glt = active_gltextures; glt; glt = glt->next)
+		{
 			if (glt->owner == owner && !strcmp (glt->name, name))
 				return glt;
+		}
 	}
 
 	return NULL;
@@ -330,7 +333,7 @@ gltexture_t *TexMgr_NewTexture (void)
 	glt->next = active_gltextures;
 	active_gltextures = glt;
 
-	glGenTextures(1, (GLuint *)&glt->texnum);
+	glGenTextures(1, &glt->texnum);
 	numgltextures++;
 	return glt;
 }
@@ -356,22 +359,24 @@ void TexMgr_FreeTexture (gltexture_t *kill)
 		kill->next = free_gltextures;
 		free_gltextures = kill;
 
-		glDeleteTextures(1, (const GLuint *)&kill->texnum);
+		glDeleteTextures(1, &kill->texnum);
 		numgltextures--;
 		return;
 	}
 
 	for (glt = active_gltextures; glt; glt = glt->next)
+	{
 		if (glt->next == kill)
 		{
 			glt->next = kill->next;
 			kill->next = free_gltextures;
 			free_gltextures = kill;
 
-			glDeleteTextures(1, (const GLuint *)&kill->texnum);
+			glDeleteTextures(1, &kill->texnum);
 			numgltextures--;
 			return;
 		}
+	}
 
 	Con_Printf ("TexMgr_FreeTexture: not found\n");
 }
@@ -443,7 +448,7 @@ void TexMgr_LoadPalette (void)
 	//standard palette, 255 is transparent
 	dst = (byte *)d_8to24table;
 	src = pal;
-	for (i=0; i<256; i++)
+	for (i = 0; i < 256; i++)
 	{
 		*dst++ = *src++;
 		*dst++ = *src++;
@@ -454,15 +459,15 @@ void TexMgr_LoadPalette (void)
 
 	//fullbright palette, 0-223 are black (for additive blending)
 	src = pal + 224*3;
-	dst = (byte *)(d_8to24table_fbright) + 224*4;
-	for (i=224; i<256; i++)
+	dst = (byte *) &d_8to24table_fbright[224];
+	for (i = 224; i < 256; i++)
 	{
 		*dst++ = *src++;
 		*dst++ = *src++;
 		*dst++ = *src++;
 		*dst++ = 255;
 	}
-	for (i=0; i<224; i++)
+	for (i = 0; i < 224; i++)
 	{
 		dst = (byte *) &d_8to24table_fbright[i];
 		dst[3] = 255;
@@ -472,14 +477,14 @@ void TexMgr_LoadPalette (void)
 	//nobright palette, 224-255 are black (for additive blending)
 	dst = (byte *)d_8to24table_nobright;
 	src = pal;
-	for (i=0; i<256; i++)
+	for (i = 0; i < 256; i++)
 	{
 		*dst++ = *src++;
 		*dst++ = *src++;
 		*dst++ = *src++;
 		*dst++ = 255;
 	}
-	for (i=224; i<256; i++)
+	for (i = 224; i < 256; i++)
 	{
 		dst = (byte *) &d_8to24table_nobright[i];
 		dst[3] = 255;
@@ -542,7 +547,7 @@ void TexMgr_RecalcWarpImageSize (void)
 	mark = Hunk_LowMark();
 	dummy = (byte *) Hunk_Alloc (gl_warpimagesize*gl_warpimagesize*4);
 
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
 	{
 		if (glt->flags & TEXPREF_WARPIMAGE)
 		{
@@ -572,7 +577,7 @@ void TexMgr_Init (void)
 	// init texture list
 	free_gltextures = (gltexture_t *) Hunk_AllocName (MAX_GLTEXTURES * sizeof(gltexture_t), "gltextures");
 	active_gltextures = NULL;
-	for (i=0; i<MAX_GLTEXTURES-1; i++)
+	for (i = 0; i < MAX_GLTEXTURES - 1; i++)
 		free_gltextures[i].next = &free_gltextures[i+1];
 	free_gltextures[i].next = NULL;
 	numgltextures = 0;
@@ -580,10 +585,13 @@ void TexMgr_Init (void)
 	// palette
 	TexMgr_LoadPalette ();
 
-	Cvar_RegisterVariable (&gl_max_size, NULL);
-	Cvar_RegisterVariable (&gl_picmip, NULL);
-	Cvar_RegisterVariable (&gl_texture_anisotropy, &TexMgr_Anisotropy_f);
-	Cmd_AddCommand ("gl_texturemode", &TexMgr_TextureMode_f);
+	Cvar_RegisterVariable (&gl_max_size);
+	Cvar_RegisterVariable (&gl_picmip);
+	Cvar_RegisterVariable (&gl_texture_anisotropy);
+	Cvar_SetCallback (&gl_texture_anisotropy, &TexMgr_Anisotropy_f);
+	gl_texturemode.string = glmodes[glmode_idx].name;
+	Cvar_RegisterVariable (&gl_texturemode);
+	Cvar_SetCallback (&gl_texturemode, &TexMgr_TextureMode_f);
 	Cmd_AddCommand ("gl_describetexturemodes", &TexMgr_DescribeTextureModes_f);
 	Cmd_AddCommand ("imagelist", &TexMgr_Imagelist_f);
 	Cmd_AddCommand ("imagedump", &TexMgr_Imagedump_f);
@@ -619,7 +627,8 @@ TexMgr_Pad -- return smallest power of two greater than or equal to s
 int TexMgr_Pad (int s)
 {
 	int i;
-	for (i = 1; i < s; i<<=1);
+	for (i = 1; i < s; i<<=1)
+		;
 	return i;
 }
 
@@ -655,15 +664,15 @@ int TexMgr_PadConditional (int s)
 TexMgr_MipMapW
 ================
 */
-unsigned *TexMgr_MipMapW (unsigned *data, int width, int height)
+static unsigned *TexMgr_MipMapW (unsigned *data, int width, int height)
 {
-	int		i, size;
+	int	i, size;
 	byte	*out, *in;
 
 	out = in = (byte *)data;
 	size = (width*height)>>1;
 
-	for (i=0; i<size; i++, out+=4, in+=8)
+	for (i = 0; i < size; i++, out += 4, in += 8)
 	{
 		out[0] = (in[0] + in[4])>>1;
 		out[1] = (in[1] + in[5])>>1;
@@ -679,23 +688,25 @@ unsigned *TexMgr_MipMapW (unsigned *data, int width, int height)
 TexMgr_MipMapH
 ================
 */
-unsigned *TexMgr_MipMapH (unsigned *data, int width, int height)
+static unsigned *TexMgr_MipMapH (unsigned *data, int width, int height)
 {
-	int		i, j;
+	int	i, j;
 	byte	*out, *in;
 
 	out = in = (byte *)data;
 	height>>=1;
 	width<<=2;
 
-	for (i=0; i<height; i++, in+=width)
-		for (j=0; j<width; j+=4, out+=4, in+=4)
+	for (i = 0; i < height; i++, in += width)
+	{
+		for (j = 0; j < width; j += 4, out += 4, in += 4)
 		{
 			out[0] = (in[0] + in[width+0])>>1;
 			out[1] = (in[1] + in[width+1])>>1;
 			out[2] = (in[2] + in[width+2])>>1;
 			out[3] = (in[3] + in[width+3])>>1;
 		}
+	}
 
 	return data;
 }
@@ -705,7 +716,7 @@ unsigned *TexMgr_MipMapH (unsigned *data, int width, int height)
 TexMgr_ResampleTexture -- bilinear resample
 ================
 */
-unsigned *TexMgr_ResampleTexture (unsigned *in, int inwidth, int inheight, qboolean alpha)
+static unsigned *TexMgr_ResampleTexture (unsigned *in, int inwidth, int inheight, qboolean alpha)
 {
 	byte *nwpx, *nepx, *swpx, *sepx, *dest;
 	unsigned xfrac, yfrac, x, y, modx, mody, imodx, imody, injump, outjump;
@@ -723,14 +734,14 @@ unsigned *TexMgr_ResampleTexture (unsigned *in, int inwidth, int inheight, qbool
 	yfrac = ((inheight-1) << 16) / (outheight-1);
 	y = outjump = 0;
 
-	for (i=0; i<outheight; i++)
+	for (i = 0; i < outheight; i++)
 	{
 		mody = (y>>8) & 0xFF;
 		imody = 256 - mody;
 		injump = (y>>16) * inwidth;
 		x = 0;
 
-		for (j=0; j<outwidth; j++)
+		for (j = 0; j < outwidth; j++)
 		{
 			modx = (x>>8) & 0xFF;
 			imodx = 256 - modx;
@@ -767,18 +778,20 @@ eliminate pink edges on sprites, etc.
 operates in place on 32bit data
 ===============
 */
-void TexMgr_AlphaEdgeFix (byte *data, int width, int height)
+static void TexMgr_AlphaEdgeFix (byte *data, int width, int height)
 {
-	int i,j,n=0,b,c[3]={0,0,0},lastrow,thisrow,nextrow,lastpix,thispix,nextpix;
-	byte *dest = data;
+	int	i, j, n = 0, b, c[3] = {0,0,0},
+		lastrow, thisrow, nextrow,
+		lastpix, thispix, nextpix;
+	byte	*dest = data;
 
-	for (i=0; i<height; i++)
+	for (i = 0; i < height; i++)
 	{
 		lastrow = width * 4 * ((i == 0) ? height-1 : i-1);
 		thisrow = width * 4 * i;
 		nextrow = width * 4 * ((i == height-1) ? 0 : i+1);
 
-		for (j=0; j<width; j++, dest+=4)
+		for (j = 0; j < width; j++, dest += 4)
 		{
 			if (dest[3]) //not transparent
 				continue;
@@ -816,7 +829,7 @@ TexMgr_PadEdgeFixW -- special case of AlphaEdgeFix for textures that only need i
 operates in place on 32bit data, and expects unpadded height and width values
 ===============
 */
-void TexMgr_PadEdgeFixW (byte *data, int width, int height)
+static void TexMgr_PadEdgeFixW (byte *data, int width, int height)
 {
 	byte *src, *dst;
 	int i, padw, padh;
@@ -826,7 +839,7 @@ void TexMgr_PadEdgeFixW (byte *data, int width, int height)
 
 	//copy last full column to first empty column, leaving alpha byte at zero
 	src = data + (width - 1) * 4;
-	for (i=0; i<padh; i++)
+	for (i = 0; i < padh; i++)
 	{
 		src[4] = src[0];
 		src[5] = src[1];
@@ -837,7 +850,7 @@ void TexMgr_PadEdgeFixW (byte *data, int width, int height)
 	//copy first full column to last empty column, leaving alpha byte at zero
 	src = data;
 	dst = data + (padw - 1) * 4;
-	for (i=0; i<padh; i++)
+	for (i = 0; i < padh; i++)
 	{
 		dst[0] = src[0];
 		dst[1] = src[1];
@@ -854,7 +867,7 @@ TexMgr_PadEdgeFixH -- special case of AlphaEdgeFix for textures that only need i
 operates in place on 32bit data, and expects unpadded height and width values
 ===============
 */
-void TexMgr_PadEdgeFixH (byte *data, int width, int height)
+static void TexMgr_PadEdgeFixH (byte *data, int width, int height)
 {
 	byte *src, *dst;
 	int i, padw, padh;
@@ -865,7 +878,7 @@ void TexMgr_PadEdgeFixH (byte *data, int width, int height)
 	//copy last full row to first empty row, leaving alpha byte at zero
 	dst = data + height * padw * 4;
 	src = dst - padw * 4;
-	for (i=0; i<padw; i++)
+	for (i = 0; i < padw; i++)
 	{
 		dst[0] = src[0];
 		dst[1] = src[1];
@@ -877,7 +890,7 @@ void TexMgr_PadEdgeFixH (byte *data, int width, int height)
 	//copy first full row to last empty row, leaving alpha byte at zero
 	dst = data + (padh - 1) * padw * 4;
 	src = data;
-	for (i=0; i<padw; i++)
+	for (i = 0; i < padw; i++)
 	{
 		dst[0] = src[0];
 		dst[1] = src[1];
@@ -892,14 +905,14 @@ void TexMgr_PadEdgeFixH (byte *data, int width, int height)
 TexMgr_8to32
 ================
 */
-unsigned *TexMgr_8to32 (byte *in, int pixels, unsigned int *usepal)
+static unsigned *TexMgr_8to32 (byte *in, int pixels, unsigned int *usepal)
 {
 	int i;
 	unsigned *out, *data;
 
 	out = data = (unsigned *) Hunk_Alloc(pixels*4);
 
-	for (i=0 ; i<pixels ; i++)
+	for (i = 0; i < pixels; i++)
 		*out++ = usepal[*in++];
 
 	return data;
@@ -910,7 +923,7 @@ unsigned *TexMgr_8to32 (byte *in, int pixels, unsigned int *usepal)
 TexMgr_PadImageW -- return image with width padded up to power-of-two dimentions
 ================
 */
-byte *TexMgr_PadImageW (byte *in, int width, int height, byte padbyte)
+static byte *TexMgr_PadImageW (byte *in, int width, int height, byte padbyte)
 {
 	int i, j, outwidth;
 	byte *out, *data;
@@ -922,11 +935,11 @@ byte *TexMgr_PadImageW (byte *in, int width, int height, byte padbyte)
 
 	out = data = (byte *) Hunk_Alloc(outwidth*height);
 
-	for (i=0; i<height; i++)
+	for (i = 0; i < height; i++)
 	{
-		for (j=0; j<width; j++)
+		for (j = 0; j < width; j++)
 			*out++ = *in++;
-		for (   ; j<outwidth; j++)
+		for (  ; j < outwidth; j++)
 			*out++ = padbyte;
 	}
 
@@ -938,7 +951,7 @@ byte *TexMgr_PadImageW (byte *in, int width, int height, byte padbyte)
 TexMgr_PadImageH -- return image with height padded up to power-of-two dimentions
 ================
 */
-byte *TexMgr_PadImageH (byte *in, int width, int height, byte padbyte)
+static byte *TexMgr_PadImageH (byte *in, int width, int height, byte padbyte)
 {
 	int i, srcpix, dstpix;
 	byte *data, *out;
@@ -951,9 +964,9 @@ byte *TexMgr_PadImageH (byte *in, int width, int height, byte padbyte)
 
 	out = data = (byte *) Hunk_Alloc(dstpix);
 
-	for (i=0; i<srcpix; i++)
+	for (i = 0; i < srcpix; i++)
 		*out++ = *in++;
-	for (   ; i<dstpix; i++)
+	for (     ; i < dstpix; i++)
 		*out++ = padbyte;
 
 	return data;
@@ -964,7 +977,7 @@ byte *TexMgr_PadImageH (byte *in, int width, int height, byte padbyte)
 TexMgr_LoadImage32 -- handles 32bit source data
 ================
 */
-void TexMgr_LoadImage32 (gltexture_t *glt, unsigned *data)
+static void TexMgr_LoadImage32 (gltexture_t *glt, unsigned *data)
 {
 	int	internalformat,	miplevel, mipwidth, mipheight, picmip;
 
@@ -977,14 +990,14 @@ void TexMgr_LoadImage32 (gltexture_t *glt, unsigned *data)
 	picmip = (glt->flags & TEXPREF_NOPICMIP) ? 0 : q_max((int)gl_picmip.value, 0);
 	mipwidth = TexMgr_SafeTextureSize (glt->width >> picmip);
 	mipheight = TexMgr_SafeTextureSize (glt->height >> picmip);
-	while (glt->width > mipwidth)
+	while ((int) glt->width > mipwidth)
 	{
 		TexMgr_MipMapW (data, glt->width, glt->height);
 		glt->width >>= 1;
 		if (glt->flags & TEXPREF_ALPHA)
 			TexMgr_AlphaEdgeFix ((byte *)data, glt->width, glt->height);
 	}
-	while (glt->height > mipheight)
+	while ((int) glt->height > mipheight)
 	{
 		TexMgr_MipMapH (data, glt->width, glt->height);
 		glt->height >>= 1;
@@ -1028,7 +1041,7 @@ void TexMgr_LoadImage32 (gltexture_t *glt, unsigned *data)
 TexMgr_LoadImage8 -- handles 8bit source data, then passes it to LoadImage32
 ================
 */
-void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
+static void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
 {
 	extern cvar_t gl_fullbrights;
 	qboolean padw = false, padh = false;
@@ -1037,7 +1050,9 @@ void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
 	int i;
 
 	// HACK HACK HACK -- taken from tomazquake
-	if (strstr(glt->name, "shot1sid") && glt->width==32 && glt->height==32 && CRC_Block(data, 1024) == 65393)
+	if (strstr(glt->name, "shot1sid") &&
+	    glt->width == 32 && glt->height == 32 &&
+	    CRC_Block(data, 1024) == 65393)
 	{
 		// This texture in b_shell1.bsp has some of the first 32 pixels painted white.
 		// They are invisible in software, but look really ugly in GL. So we just copy
@@ -1048,10 +1063,10 @@ void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
 	// detect false alpha cases
 	if (glt->flags & TEXPREF_ALPHA && !(glt->flags & TEXPREF_CONCHARS))
 	{
-		for (i = 0; i < glt->width*glt->height; i++)
+		for (i = 0; i < (int) (glt->width * glt->height); i++)
 			if (data[i] == 255) //transparent index
 				break;
-		if (i == glt->width*glt->height)
+		if (i == (int) (glt->width * glt->height))
 			glt->flags -= TEXPREF_ALPHA;
 	}
 
@@ -1080,13 +1095,13 @@ void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
 	// pad each dimention, but only if it's not going to be downsampled later
 	if (glt->flags & TEXPREF_PAD)
 	{
-		if (glt->width < TexMgr_SafeTextureSize(glt->width))
+		if ((int) glt->width < TexMgr_SafeTextureSize(glt->width))
 		{
 			data = TexMgr_PadImageW (data, glt->width, glt->height, padbyte);
 			glt->width = TexMgr_Pad(glt->width);
 			padw = true;
 		}
-		if (glt->height < TexMgr_SafeTextureSize(glt->height))
+		if ((int) glt->height < TexMgr_SafeTextureSize(glt->height))
 		{
 			data = TexMgr_PadImageH (data, glt->width, glt->height, padbyte);
 			glt->height = TexMgr_Pad(glt->height);
@@ -1117,10 +1132,8 @@ void TexMgr_LoadImage8 (gltexture_t *glt, byte *data)
 TexMgr_LoadLightmap -- handles lightmap data
 ================
 */
-void TexMgr_LoadLightmap (gltexture_t *glt, byte *data)
+static void TexMgr_LoadLightmap (gltexture_t *glt, byte *data)
 {
-	extern int gl_lightmap_format, lightmap_bytes;
-
 	// upload it
 	GL_Bind (glt);
 	glTexImage2D (GL_TEXTURE_2D, 0, lightmap_bytes, glt->width, glt->height, 0, gl_lightmap_format, GL_UNSIGNED_BYTE, data);
@@ -1137,7 +1150,6 @@ TexMgr_LoadImage -- the one entry point for loading all textures
 gltexture_t *TexMgr_LoadImage (model_t *owner, const char *name, int width, int height, enum srcformat format,
 			       byte *data, const char *source_file, src_offset_t source_offset, unsigned flags)
 {
-	extern int lightmap_bytes;
 	unsigned short crc;
 	gltexture_t *glt;
 	int mark;
@@ -1148,17 +1160,17 @@ gltexture_t *TexMgr_LoadImage (model_t *owner, const char *name, int width, int
 	// cache check
 	switch (format)
 	{
-		case SRC_INDEXED:
-			crc = CRC_Block(data, width * height);
-			break;
-		case SRC_LIGHTMAP:
-			crc = CRC_Block(data, width * height * lightmap_bytes);
-			break;
-		case SRC_RGBA:
-			crc = CRC_Block(data, width * height * 4);
-			break;
-		default: /* not reachable but avoids compiler warnings */
-			crc = 0;
+	case SRC_INDEXED:
+		crc = CRC_Block(data, width * height);
+		break;
+	case SRC_LIGHTMAP:
+		crc = CRC_Block(data, width * height * lightmap_bytes);
+		break;
+	case SRC_RGBA:
+		crc = CRC_Block(data, width * height * 4);
+		break;
+	default: /* not reachable but avoids compiler warnings */
+		crc = 0;
 	}
 	if ((flags & TEXPREF_OVERWRITE) && (glt = TexMgr_FindTexture (owner, name)))
 	{
@@ -1170,13 +1182,13 @@ gltexture_t *TexMgr_LoadImage (model_t *owner, const char *name, int width, int
 
 	// copy data
 	glt->owner = owner;
-	strncpy (glt->name, name, sizeof(glt->name));
+	q_strlcpy (glt->name, name, sizeof(glt->name));
 	glt->width = width;
 	glt->height = height;
 	glt->flags = flags;
 	glt->shirt = -1;
 	glt->pants = -1;
-	strncpy (glt->source_file, source_file, sizeof(glt->source_file));
+	q_strlcpy (glt->source_file, source_file, sizeof(glt->source_file));
 	glt->source_offset = source_offset;
 	glt->source_format = format;
 	glt->source_width = width;
@@ -1188,15 +1200,15 @@ gltexture_t *TexMgr_LoadImage (model_t *owner, const char *name, int width, int
 
 	switch (glt->source_format)
 	{
-		case SRC_INDEXED:
-			TexMgr_LoadImage8 (glt, data);
-			break;
-		case SRC_LIGHTMAP:
-			TexMgr_LoadLightmap (glt, data);
-			break;
-		case SRC_RGBA:
-			TexMgr_LoadImage32 (glt, (unsigned *)data);
-			break;
+	case SRC_INDEXED:
+		TexMgr_LoadImage8 (glt, data);
+		break;
+	case SRC_LIGHTMAP:
+		TexMgr_LoadLightmap (glt, data);
+		break;
+	case SRC_RGBA:
+		TexMgr_LoadImage32 (glt, (unsigned *)data);
+		break;
 	}
 
 	Hunk_FreeToLowMark(mark);
@@ -1221,7 +1233,7 @@ void TexMgr_ReloadImage (gltexture_t *glt, int shirt, int pants)
 {
 	byte	translation[256];
 	byte	*src, *dst, *data = NULL, *translated;
-	int		mark, size, i;
+	int	mark, size, i;
 //
 // get source data
 //
@@ -1230,10 +1242,21 @@ void TexMgr_ReloadImage (gltexture_t *glt, int shirt, int pants)
 	if (glt->source_file[0] && glt->source_offset)
 	{
 		//lump inside file
-		data = COM_LoadHunkFile (glt->source_file, NULL);
-		if (!data)
+		long size;
+		FILE *f;
+		COM_FOpenFile(glt->source_file, &f, NULL);
+		if (!f)
 			goto invalid;
-		data += glt->source_offset;
+		fseek (f, glt->source_offset, SEEK_CUR);
+		size = (long) (glt->source_width * glt->source_height);
+		/* should be SRC_INDEXED, but no harm being paranoid:  */
+		if (glt->source_format == SRC_RGBA)
+			size *= 4;
+		else if (glt->source_format == SRC_LIGHTMAP)
+			size *= lightmap_bytes;
+		data = (byte *) Hunk_Alloc (size);
+		fread (data, 1, size, f);
+		fclose (f);
 	}
 	else if (glt->source_file[0] && !glt->source_offset)
 		data = Image_LoadImage (glt->source_file, (int *)&glt->source_width, (int *)&glt->source_height); //simple file
@@ -1268,31 +1291,39 @@ invalid:
 	if (glt->shirt > -1 && glt->pants > -1)
 	{
 		//create new translation table
-		for (i=0 ; i<256 ; i++)
+		for (i = 0; i < 256; i++)
 			translation[i] = i;
 
 		shirt = glt->shirt * 16;
 		if (shirt < 128)
-			for (i=0 ; i<16 ; i++)
-				translation[TOP_RANGE+i] = shirt+i;
+		{
+			for (i = 0; i < 16; i++)
+				translation[TOP_RANGE+i] = shirt + i;
+		}
 		else
-			for (i=0 ; i<16 ; i++)
+		{
+			for (i = 0; i < 16; i++)
 				translation[TOP_RANGE+i] = shirt+15-i;
+		}
 
 		pants = glt->pants * 16;
 		if (pants < 128)
-			for (i=0 ; i<16 ; i++)
-				translation[BOTTOM_RANGE+i] = pants+i;
+		{
+			for (i = 0; i < 16; i++)
+				translation[BOTTOM_RANGE+i] = pants + i;
+		}
 		else
-			for (i=0 ; i<16 ; i++)
+		{
+			for (i = 0; i < 16; i++)
 				translation[BOTTOM_RANGE+i] = pants+15-i;
+		}
 
 		//translate texture
 		size = glt->width * glt->height;
 		dst = translated = (byte *) Hunk_Alloc (size);
 		src = data;
 
-		for (i=0; i<size; i++)
+		for (i = 0; i < size; i++)
 			*dst++ = translation[*src++];
 
 		data = translated;
@@ -1302,15 +1333,15 @@ invalid:
 //
 	switch (glt->source_format)
 	{
-		case SRC_INDEXED:
-			TexMgr_LoadImage8 (glt, data);
-			break;
-		case SRC_LIGHTMAP:
-			TexMgr_LoadLightmap (glt, data);
-			break;
-		case SRC_RGBA:
-			TexMgr_LoadImage32 (glt, (unsigned *)data);
-			break;
+	case SRC_INDEXED:
+		TexMgr_LoadImage8 (glt, data);
+		break;
+	case SRC_LIGHTMAP:
+		TexMgr_LoadLightmap (glt, data);
+		break;
+	case SRC_RGBA:
+		TexMgr_LoadImage32 (glt, (unsigned *)data);
+		break;
 	}
 
 	Hunk_FreeToLowMark(mark);
@@ -1325,9 +1356,9 @@ void TexMgr_ReloadImages (void)
 {
 	gltexture_t *glt;
 
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
 	{
-		glGenTextures(1, (GLuint *)&glt->texnum);
+		glGenTextures(1, &glt->texnum);
 		TexMgr_ReloadImage (glt, -1, -1);
 	}
 }
@@ -1341,7 +1372,7 @@ void TexMgr_ReloadNobrightImages (void)
 {
 	gltexture_t *glt;
 
-	for (glt=active_gltextures; glt; glt=glt->next)
+	for (glt = active_gltextures; glt; glt = glt->next)
 		if (glt->flags & TEXPREF_NOBRIGHT)
 			TexMgr_ReloadImage(glt, -1, -1);
 }
@@ -1354,19 +1385,19 @@ void TexMgr_ReloadNobrightImages (void)
 ================================================================================
 */
 
-int	currenttexture = -1; // to avoid unnecessary texture sets
-GLenum TEXTURE0, TEXTURE1; //johnfitz
-qboolean mtexenabled = false;
+static GLuint	currenttexture = (GLuint)-1; // to avoid unnecessary texture sets
+GLenum		TEXTURE0, TEXTURE1; //johnfitz
+qboolean	mtexenabled = false;
 
 /*
 ================
 GL_SelectTexture -- johnfitz -- rewritten
 ================
 */
-void GL_SelectTexture (GLenum target)
+static void GL_SelectTexture (GLenum target)
 {
 	static GLenum currenttarget;
-	static int ct0, ct1;
+	static GLuint ct0, ct1;
 
 	if (target == currenttarget)
 		return;
