@@ -36,7 +36,7 @@ Memory is cleared / released when a server or client begins, not when they end.
 
 */
 
-quakeparms_t host_parms;
+quakeparms_t *host_parms;
 
 qboolean	host_initialized;		// true if into command execution
 
@@ -44,11 +44,12 @@ double		host_frametime;
 double		host_time;
 double		realtime;				// without any filtering or bounding
 double		oldrealtime;			// last frame run
-int			host_framecount;
 
-int			host_hunklevel;
+int		host_framecount;
 
-int			minimum_memory;
+int		host_hunklevel;
+
+int		minimum_memory;
 
 client_t	*host_client;			// current client
 
@@ -56,31 +57,31 @@ jmp_buf 	host_abortserver;
 
 byte		*host_colormap;
 
-cvar_t	host_framerate = {"host_framerate","0"};	// set for slow motion
-cvar_t	host_speeds = {"host_speeds","0"};			// set for running times
-cvar_t	host_maxfps = {"host_maxfps", "72", true}; //johnfitz
-cvar_t	host_timescale = {"host_timescale", "0"}; //johnfitz
-cvar_t	max_edicts = {"max_edicts", STR(DEF_EDICTS), true}; //johnfitz
+cvar_t	host_framerate = {"host_framerate","0",CVAR_NONE};	// set for slow motion
+cvar_t	host_speeds = {"host_speeds","0",CVAR_NONE};			// set for running times
+cvar_t	host_maxfps = {"host_maxfps", "72", CVAR_ARCHIVE}; //johnfitz
+cvar_t	host_timescale = {"host_timescale", "0", CVAR_NONE}; //johnfitz
+cvar_t	max_edicts = {"max_edicts", STR(DEF_EDICTS), CVAR_ARCHIVE}; //johnfitz
 
-cvar_t	sys_ticrate = {"sys_ticrate","0.05"}; // dedicated server
-cvar_t	serverprofile = {"serverprofile","0"};
+cvar_t	sys_ticrate = {"sys_ticrate","0.05",CVAR_NONE}; // dedicated server
+cvar_t	serverprofile = {"serverprofile","0",CVAR_NONE};
 
-cvar_t	fraglimit = {"fraglimit","0",false,true};
-cvar_t	timelimit = {"timelimit","0",false,true};
-cvar_t	teamplay = {"teamplay","0",false,true};
-cvar_t	samelevel = {"samelevel","0"};
-cvar_t	noexit = {"noexit","0",false,true};
-cvar_t	skill = {"skill","1"};						// 0 - 3
-cvar_t	deathmatch = {"deathmatch","0"};			// 0, 1, or 2
-cvar_t	coop = {"coop","0"};			// 0 or 1
+cvar_t	fraglimit = {"fraglimit","0",CVAR_NOTIFY|CVAR_SERVERINFO};
+cvar_t	timelimit = {"timelimit","0",CVAR_NOTIFY|CVAR_SERVERINFO};
+cvar_t	teamplay = {"teamplay","0",CVAR_NOTIFY|CVAR_SERVERINFO};
+cvar_t	samelevel = {"samelevel","0",CVAR_NONE};
+cvar_t	noexit = {"noexit","0",CVAR_NOTIFY|CVAR_SERVERINFO};
+cvar_t	skill = {"skill","1",CVAR_NONE};			// 0 - 3
+cvar_t	deathmatch = {"deathmatch","0",CVAR_NONE};	// 0, 1, or 2
+cvar_t	coop = {"coop","0",CVAR_NONE};			// 0 or 1
 
-cvar_t	pausable = {"pausable","1"};
+cvar_t	pausable = {"pausable","1",CVAR_NONE};
 
-cvar_t	developer = {"developer","0"};
+cvar_t	developer = {"developer","0",CVAR_NONE};
 
-cvar_t	temp1 = {"temp1","0"};
+cvar_t	temp1 = {"temp1","0",CVAR_NONE};
 
-cvar_t devstats = {"devstats","0"}; //johnfitz -- track developer statistics that vary every frame
+cvar_t devstats = {"devstats","0",CVAR_NONE}; //johnfitz -- track developer statistics that vary every frame
 
 devstats_t dev_stats, dev_peakstats;
 overflowtimes_t dev_overflows; //this stores the last time overflow messages were displayed, not the last time overflows occured
@@ -90,12 +91,11 @@ overflowtimes_t dev_overflows; //this stores the last time overflow messages wer
 Max_Edicts_f -- johnfitz
 ================
 */
-void Max_Edicts_f (void)
+static void Max_Edicts_f (cvar_t *var)
 {
 	static float oldval = DEF_EDICTS; //must match the default value for max_edicts
 
 	//TODO: clamp it here?
-
 	if (max_edicts.value == oldval)
 		return;
 
@@ -219,9 +219,23 @@ void	Host_FindMaxClients (void)
 	svs.clients = (struct client_s *) Hunk_AllocName (svs.maxclientslimit*sizeof(client_t), "clients");
 
 	if (svs.maxclients > 1)
-		Cvar_SetValue ("deathmatch", 1.0);
+		Cvar_SetQuick (&deathmatch, "1");
 	else
-		Cvar_SetValue ("deathmatch", 0.0);
+		Cvar_SetQuick (&deathmatch, "0");
+}
+
+void Host_Version_f (void)
+{
+	Con_Printf ("Quake Version %1.2f\n", VERSION);
+	Con_Printf ("QuakeSpasm Version %1.2f.%d\n", FITZQUAKE_VERSION, QUAKESPASM_VER_PATCH);
+	Con_Printf ("Exe: "__TIME__" "__DATE__"\n");
+}
+
+/* cvar callback functions : */
+void Host_Callback_Notify (cvar_t *var)
+{
+	if (sv.active)
+		SV_BroadcastPrintf ("\"%s\" changed to \"%s\"\n", var->name, var->string);
 }
 
 /*
@@ -231,33 +245,40 @@ Host_InitLocal
 */
 void Host_InitLocal (void)
 {
+	Cmd_AddCommand ("version", Host_Version_f);
+
 	Host_InitCommands ();
 
-	Cvar_RegisterVariable (&host_framerate, NULL);
-	Cvar_RegisterVariable (&host_speeds, NULL);
-	Cvar_RegisterVariable (&host_maxfps, NULL); //johnfitz
-	Cvar_RegisterVariable (&host_timescale, NULL); //johnfitz
+	Cvar_RegisterVariable (&host_framerate);
+	Cvar_RegisterVariable (&host_speeds);
+	Cvar_RegisterVariable (&host_maxfps); //johnfitz
+	Cvar_RegisterVariable (&host_timescale); //johnfitz
 
-	Cvar_RegisterVariable (&max_edicts, Max_Edicts_f); //johnfitz
-	Cvar_RegisterVariable (&devstats, NULL); //johnfitz
+	Cvar_RegisterVariable (&max_edicts); //johnfitz
+	Cvar_SetCallback (&max_edicts, Max_Edicts_f);
+	Cvar_RegisterVariable (&devstats); //johnfitz
 
-	Cvar_RegisterVariable (&sys_ticrate, NULL);
-	Cvar_RegisterVariable (&sys_throttle, NULL);
-	Cvar_RegisterVariable (&serverprofile, NULL);
+	Cvar_RegisterVariable (&sys_ticrate);
+	Cvar_RegisterVariable (&sys_throttle);
+	Cvar_RegisterVariable (&serverprofile);
 
-	Cvar_RegisterVariable (&fraglimit, NULL);
-	Cvar_RegisterVariable (&timelimit, NULL);
-	Cvar_RegisterVariable (&teamplay, NULL);
-	Cvar_RegisterVariable (&samelevel, NULL);
-	Cvar_RegisterVariable (&noexit, NULL);
-	Cvar_RegisterVariable (&skill, NULL);
-	Cvar_RegisterVariable (&developer, NULL);
-	Cvar_RegisterVariable (&deathmatch, NULL);
-	Cvar_RegisterVariable (&coop, NULL);
+	Cvar_RegisterVariable (&fraglimit);
+	Cvar_RegisterVariable (&timelimit);
+	Cvar_RegisterVariable (&teamplay);
+	Cvar_SetCallback (&fraglimit, Host_Callback_Notify);
+	Cvar_SetCallback (&timelimit, Host_Callback_Notify);
+	Cvar_SetCallback (&teamplay, Host_Callback_Notify);
+	Cvar_RegisterVariable (&samelevel);
+	Cvar_RegisterVariable (&noexit);
+	Cvar_SetCallback (&noexit, Host_Callback_Notify);
+	Cvar_RegisterVariable (&skill);
+	Cvar_RegisterVariable (&developer);
+	Cvar_RegisterVariable (&coop);
+	Cvar_RegisterVariable (&deathmatch);
 
-	Cvar_RegisterVariable (&pausable, NULL);
+	Cvar_RegisterVariable (&pausable);
 
-	Cvar_RegisterVariable (&temp1, NULL);
+	Cvar_RegisterVariable (&temp1);
 
 	Host_FindMaxClients ();
 
@@ -473,7 +494,7 @@ void Host_ShutdownServer(qboolean crash)
 		CL_Disconnect ();
 
 // flush any pending messages - like the score!!!
-	start = Sys_FloatTime();
+	start = Sys_DoubleTime();
 	do
 	{
 		count = 0;
@@ -493,7 +514,7 @@ void Host_ShutdownServer(qboolean crash)
 				}
 			}
 		}
-		if ((Sys_FloatTime() - start) > 3.0)
+		if ((Sys_DoubleTime() - start) > 3.0)
 			break;
 	}
 	while (count);
@@ -532,9 +553,8 @@ void Host_ClearMemory (void)
 	Con_DPrintf ("Clearing memory\n");
 	D_FlushCaches ();
 	Mod_ClearAll ();
-	if (host_hunklevel)
-		Hunk_FreeToLowMark (host_hunklevel);
-
+/* host_hunklevel MUST be set at this point */
+	Hunk_FreeToLowMark (host_hunklevel);
 	cls.signon = 0;
 	memset (&sv, 0, sizeof(sv));
 	memset (&cl, 0, sizeof(cl));
@@ -590,7 +610,10 @@ Add them exactly as if they had been typed at the console
 */
 void Host_GetConsoleCommands (void)
 {
-	char	*cmd;
+	const char	*cmd;
+
+	if (!isDedicated)
+		return;	// no stdin necessary in graphical mode
 
 	while (1)
 	{
@@ -673,7 +696,7 @@ void _Host_Frame (float time)
 		return;			// don't run too fast, or packets will flood out
 
 // get new key events
-	//Sys_SendKeyEvents (); not needed for SDL
+	Sys_SendKeyEvents ();
 
 // allow mice or other external controllers to add commands
 	IN_Commands ();
@@ -720,14 +743,14 @@ void _Host_Frame (float time)
 
 // update video
 	if (host_speeds.value)
-		time1 = Sys_FloatTime ();
+		time1 = Sys_DoubleTime ();
 
 	SCR_UpdateScreen ();
 
 	CL_RunParticles (); //johnfitz -- seperated from rendering
 
 	if (host_speeds.value)
-		time2 = Sys_FloatTime ();
+		time2 = Sys_DoubleTime ();
 
 // update audio
 	BGM_Update();	// adds music raw samples and/or advances midi driver
@@ -744,7 +767,7 @@ void _Host_Frame (float time)
 	if (host_speeds.value)
 	{
 		pass1 = (time1 - time3)*1000;
-		time3 = Sys_FloatTime ();
+		time3 = Sys_DoubleTime ();
 		pass2 = (time2 - time1)*1000;
 		pass3 = (time3 - time2)*1000;
 		Con_Printf ("%3i tot %3i server %3i gfx %3i snd\n",
@@ -768,9 +791,9 @@ void Host_Frame (float time)
 		return;
 	}
 
-	time1 = Sys_FloatTime ();
+	time1 = Sys_DoubleTime ();
 	_Host_Frame (time);
-	time2 = Sys_FloatTime ();
+	time2 = Sys_DoubleTime ();
 
 	timetotal += time2 - time1;
 	timecount++;
@@ -796,7 +819,7 @@ void Host_Frame (float time)
 Host_Init
 ====================
 */
-void Host_Init (quakeparms_t *parms)
+void Host_Init (void)
 {
 	if (standard_quake)
 		minimum_memory = MINIMUM_MEMORY;
@@ -804,22 +827,21 @@ void Host_Init (quakeparms_t *parms)
 		minimum_memory = MINIMUM_MEMORY_LEVELPAK;
 
 	if (COM_CheckParm ("-minmemory"))
-		parms->memsize = minimum_memory;
+		host_parms->memsize = minimum_memory;
 
-	host_parms = *parms;
+	if (host_parms->memsize < minimum_memory)
+		Sys_Error ("Only %4.1f megs of memory available, can't execute game", host_parms->memsize / (float)0x100000);
 
-	if (parms->memsize < minimum_memory)
-		Sys_Error ("Only %4.1f megs of memory available, can't execute game", parms->memsize / (float)0x100000);
+	com_argc = host_parms->argc;
+	com_argv = host_parms->argv;
 
-	com_argc = parms->argc;
-	com_argv = parms->argv;
-
-	Memory_Init (parms->membase, parms->memsize);
+	Memory_Init (host_parms->membase, host_parms->memsize);
 	Cbuf_Init ();
 	Cmd_Init ();
-	LOG_Init (parms);
+	LOG_Init (host_parms);
 	Cvar_Init (); //johnfitz
-	COM_Init (parms->basedir);
+	COM_Init ();
+	COM_InitFilesystem ();
 	Host_InitLocal ();
 	W_LoadWadFile (); //johnfitz -- filename is now hard-coded for honesty
 	if (cls.state != ca_dedicated)
@@ -833,7 +855,7 @@ void Host_Init (quakeparms_t *parms)
 	SV_Init ();
 
 	Con_Printf ("Exe: "__TIME__" "__DATE__"\n");
-	Con_Printf ("%4.1f megabyte heap\n",parms->memsize/ (1024*1024.0));
+	Con_Printf ("%4.1f megabyte heap\n", host_parms->memsize/ (1024*1024.0));
 
 	if (cls.state != ca_dedicated)
 	{
@@ -857,21 +879,21 @@ void Host_Init (quakeparms_t *parms)
 		BGM_Init();
 		Sbar_Init ();
 		CL_Init ();
-
-		Cbuf_InsertText ("exec quake.rc\n");
-	//	Cbuf_InsertText ("exec fitzquake.rc\n"); //johnfitz (inserted second so it'll be executed first)
-
-	// johnfitz -- in case the vid mode was locked during vid_init, we can unlock it now.
-		// note: two leading newlines because the command buffer swallows one of them.
-		Cbuf_AddText ("\n\nvid_unlock\n");
 	}
 
 	Hunk_AllocName (0, "-HOST_HUNKLEVEL-");
 	host_hunklevel = Hunk_LowMark ();
 
 	host_initialized = true;
+	Con_Printf ("\n========= Quake Initialized =========\n\n");
 
-	Con_Printf ("\n========= Quake Initialized =========\n\n"); //johnfitz - was Sys_Printf
+	if (cls.state != ca_dedicated)
+	{
+		Cbuf_InsertText ("exec quake.rc\n");
+	// johnfitz -- in case the vid mode was locked during vid_init, we can unlock it now.
+		// note: two leading newlines because the command buffer swallows one of them.
+		Cbuf_AddText ("\n\nvid_unlock\n");
+	}
 
 	if (cls.state == ca_dedicated)
 	{
