@@ -39,8 +39,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	X11_VERSION		1.10
 
 #define	FITZQUAKE_VERSION	0.85	//johnfitz
-#define	QUAKESPASM_VERSION	0.4
-#define	QUAKESPASM_VER_PATCH	4	// helper to print a string like 0.85.4
+#define	QUAKESPASM_VERSION	0.7
+#define	QUAKESPASM_VER_PATCH	7	// helper to print a string like 0.85.7
 
 //define	PARANOID			// speed sapping error checking
 
@@ -73,6 +73,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define	ON_EPSILON		0.1			// point on plane side epsilon
 
+#define	DIST_EPSILON		(0.03125)		// 1/32 epsilon to keep floating point happy (moved from world.c)
+
 #define	MAX_MSGLEN		32000	// max length of a reliable message //johnfitz -- was 8000
 #define	MAX_DATAGRAM		32000	// max length of unreliable message //johnfitz -- was 1024
 
@@ -202,54 +204,43 @@ typedef struct
 
 #include "common.h"
 #include "bspfile.h"
-#include "vid.h"
 #include "sys.h"
 #include "zone.h"
 #include "mathlib.h"
+#include "cvar.h"
+
+#include "protocol.h"
+#include "net.h"
+
+#include "cmd.h"
+#include "crc.h"
+
+#include "progs.h"
+#include "server.h"
 
 #include "platform.h"
-
 #include "SDL.h"
 #include "SDL_opengl.h"
 
-typedef struct
-{
-	vec3_t		origin;
-	vec3_t		angles;
-	unsigned short 	modelindex;	//johnfitz -- was int
-	unsigned short 	frame;		//johnfitz -- was int
-	unsigned char 	colormap;	//johnfitz -- was int
-	unsigned char 	skin;		//johnfitz -- was int
-	unsigned char	alpha;		//johnfitz -- added
-	int		effects;
-} entity_state_t;
-
-
+#include "console.h"
 #include "wad.h"
-#include "cvar.h"
+#include "vid.h"
 #include "screen.h"
 #include "draw.h"
-#include "net.h"
-#include "protocol.h"
-#include "cmd.h"
+#include "render.h"
+#include "view.h"
 #include "sbar.h"
 #include "q_sound.h"
-#include "render.h"
 #include "client.h"
-#include "progs.h"
-#include "server.h"
+
 #include "gl_model.h"
+#include "world.h"
 
 #include "image.h"	//johnfitz
 #include "gl_texmgr.h"	//johnfitz
-
 #include "input.h"
-#include "world.h"
 #include "keys.h"
-#include "console.h"
-#include "view.h"
 #include "menu.h"
-#include "crc.h"
 #include "cdaudio.h"
 #include "glquake.h"
 
@@ -265,7 +256,7 @@ extern qboolean noclip_anglehack;
 //
 // host
 //
-extern	quakeparms_t host_parms;
+extern	quakeparms_t *host_parms;
 
 extern	cvar_t		sys_ticrate;
 extern	cvar_t		sys_throttle;
@@ -283,8 +274,9 @@ extern	double		realtime;		// not bounded in any way, changed at
 void Host_ClearMemory (void);
 void Host_ServerFrame (void);
 void Host_InitCommands (void);
-void Host_Init (quakeparms_t *parms);
+void Host_Init (void);
 void Host_Shutdown(void);
+void Host_Callback_Notify (cvar_t *var);	/* callback function for CVAR_NOTIFY */
 void Host_Error (const char *error, ...) __attribute__((__format__(__printf__,1,2), __noreturn__));
 void Host_EndGame (const char *message, ...) __attribute__((__format__(__printf__,1,2), __noreturn__));
 void Host_Frame (float time);
@@ -304,15 +296,5 @@ extern qboolean		isDedicated;
 
 extern int		minimum_memory;
 
-//
-// chase
-//
-extern	cvar_t	chase_active;
-
-void Chase_Init (void);
-void TraceLine (vec3_t start, vec3_t end, vec3_t impact);
-void Chase_UpdateForClient (void);	//johnfitz
-void Chase_UpdateForDrawing (void);	//johnfitz
-
 #endif	/* __QUAKEDEFS_H */
 
