@@ -20,6 +20,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
+
 // snd_dma.c -- main control for any streaming sound output device
 
 #include "quakedef.h"
@@ -68,22 +69,20 @@ static sfx_t	*ambient_sfx[NUM_AMBIENTS];
 
 static qboolean	sound_started = false;
 
-cvar_t		bgmvolume = {"bgmvolume", "1", true};
-cvar_t		sfxvolume = {"volume", "0.7", true};
+cvar_t		bgmvolume = {"bgmvolume", "1", CVAR_ARCHIVE};
+cvar_t		sfxvolume = {"volume", "0.7", CVAR_ARCHIVE};
 
-cvar_t		precache = {"precache", "1"};
-cvar_t		loadas8bit = {"loadas8bit", "0"};
+cvar_t		precache = {"precache", "1", CVAR_NONE};
+cvar_t		loadas8bit = {"loadas8bit", "0", CVAR_NONE};
 
-cvar_t		sndspeed = {"sndspeed", "11025"};
+cvar_t		sndspeed = {"sndspeed", "11025", CVAR_NONE};
 
-static	float	oldvolume = -1.0;
-
-static	cvar_t	nosound = {"nosound", "0"};
-static	cvar_t	ambient_level = {"ambient_level", "0.3"};
-static	cvar_t	ambient_fade = {"ambient_fade", "100"};
-static	cvar_t	snd_noextraupdate = {"snd_noextraupdate", "0"};
-static	cvar_t	snd_show = {"snd_show", "0"};
-static	cvar_t	_snd_mixahead = {"_snd_mixahead", "0.1", true};
+static	cvar_t	nosound = {"nosound", "0", CVAR_NONE};
+static	cvar_t	ambient_level = {"ambient_level", "0.3", CVAR_NONE};
+static	cvar_t	ambient_fade = {"ambient_fade", "100", CVAR_NONE};
+static	cvar_t	snd_noextraupdate = {"snd_noextraupdate", "0", CVAR_NONE};
+static	cvar_t	snd_show = {"snd_show", "0", CVAR_NONE};
+static	cvar_t	_snd_mixahead = {"_snd_mixahead", "0.1", CVAR_ARCHIVE};
 
 
 static void S_SoundInfo_f (void)
@@ -104,6 +103,12 @@ static void S_SoundInfo_f (void)
 }
 
 
+static void SND_Callback_sfxvolume (cvar_t *var)
+{
+	SND_InitScaletable ();
+}
+
+
 /*
 ================
 S_Startup
@@ -137,23 +142,25 @@ S_Init
 */
 void S_Init (void)
 {
+	int i;
+
 	if (snd_initialized)
 	{
 		Con_Printf("Sound is already initialized\n");
 		return;
 	}
 
-	Cvar_RegisterVariable(&nosound, NULL);
-	Cvar_RegisterVariable(&sfxvolume, NULL);
-	Cvar_RegisterVariable(&precache, NULL);
-	Cvar_RegisterVariable(&loadas8bit, NULL);
-	Cvar_RegisterVariable(&bgmvolume, NULL);
-	Cvar_RegisterVariable(&ambient_level, NULL);
-	Cvar_RegisterVariable(&ambient_fade, NULL);
-	Cvar_RegisterVariable(&snd_noextraupdate, NULL);
-	Cvar_RegisterVariable(&snd_show, NULL);
-	Cvar_RegisterVariable(&_snd_mixahead, NULL);
-	Cvar_RegisterVariable(&sndspeed, NULL);
+	Cvar_RegisterVariable(&nosound);
+	Cvar_RegisterVariable(&sfxvolume);
+	Cvar_RegisterVariable(&precache);
+	Cvar_RegisterVariable(&loadas8bit);
+	Cvar_RegisterVariable(&bgmvolume);
+	Cvar_RegisterVariable(&ambient_level);
+	Cvar_RegisterVariable(&ambient_fade);
+	Cvar_RegisterVariable(&snd_noextraupdate);
+	Cvar_RegisterVariable(&snd_show);
+	Cvar_RegisterVariable(&_snd_mixahead);
+	Cvar_RegisterVariable(&sndspeed);
 
 	if (safemode || COM_CheckParm("-nosound"))
 		return;
@@ -166,17 +173,20 @@ void S_Init (void)
 	Cmd_AddCommand("soundlist", S_SoundList);
 	Cmd_AddCommand("soundinfo", S_SoundInfo_f);
 
-	if (COM_CheckParm("-sndspeed"))
+	i = COM_CheckParm("-sndspeed");
+	if (i && i < com_argc-1)
 	{
-		sndspeed.value = Q_atoi(com_argv[COM_CheckParm("-sndspeed")+1]);
+		Cvar_SetQuick (&sndspeed, com_argv[i+1]);
 	}
 
-	if (host_parms.memsize < 0x800000)
+	if (host_parms->memsize < 0x800000)
 	{
-		Cvar_Set ("loadas8bit", "1");
+		Cvar_SetQuick (&loadas8bit, "1");
 		Con_Printf ("loading all sounds as 8bit\n");
 	}
 
+	Cvar_SetCallback(&sfxvolume, SND_Callback_sfxvolume);
+
 	SND_InitScaletable ();
 
 	known_sfx = (sfx_t *) Hunk_AllocName (MAX_SFX*sizeof(sfx_t), "sfx_t");
@@ -253,7 +263,7 @@ static sfx_t *S_FindName (const char *name)
 		Sys_Error ("S_FindName: out of sfx_t");
 
 	sfx = &known_sfx[i];
-	strcpy (sfx->name, name);
+	q_strlcpy (sfx->name, name, sizeof(sfx->name));
 
 	num_sfx++;
 
@@ -261,29 +271,6 @@ static sfx_t *S_FindName (const char *name)
 }
 
 
-/*
-=================
-S_FileExtension
-
-return file's extension including the dot, or NULL
-=================
-*/
-const char *S_FileExtension (const char *name)
-{
-	const char *ptr = name + strlen(name) - 1;
-
-	while (ptr > name &&
-		(*ptr != '/' && *ptr != '\\'))
-	{
-		if (*ptr == '.')
-			return ptr;
-		ptr--;
-	}
-
-	return NULL;
-}
-
-
 /*
 ==================
 S_TouchSound
@@ -780,12 +767,6 @@ void S_Update (vec3_t origin, vec3_t forward, vec3_t right, vec3_t up)
 	if (!sound_started || (snd_blocked > 0))
 		return;
 
-	if (sfxvolume.value != oldvolume)
-	{
-		oldvolume = sfxvolume.value;
-		SND_InitScaletable ();
-	}
-
 	VectorCopy(origin, listener_origin);
 	VectorCopy(forward, listener_forward);
 	VectorCopy(right, listener_right);
@@ -986,13 +967,11 @@ static void S_Play (void)
 	i = 1;
 	while (i < Cmd_Argc())
 	{
+		q_strlcpy(name, Cmd_Argv(i), sizeof(name));
 		if (!Q_strrchr(Cmd_Argv(i), '.'))
 		{
-			Q_strcpy(name, Cmd_Argv(i));
-			Q_strcat(name, ".wav");
+			q_strlcat(name, ".wav", sizeof(name));
 		}
-		else
-			Q_strcpy(name, Cmd_Argv(i));
 		sfx = S_PrecacheSound(name);
 		S_StartSound(hash++, 0, sfx, listener_origin, 1.0, 1.0);
 		i++;
@@ -1010,13 +989,11 @@ static void S_PlayVol (void)
 	i = 1;
 	while (i < Cmd_Argc())
 	{
+		q_strlcpy(name, Cmd_Argv(i), sizeof(name));
 		if (!Q_strrchr(Cmd_Argv(i), '.'))
 		{
-			Q_strcpy(name, Cmd_Argv(i));
-			Q_strcat(name, ".wav");
+			q_strlcat(name, ".wav", sizeof(name));
 		}
-		else
-			Q_strcpy(name, Cmd_Argv(i));
 		sfx = S_PrecacheSound(name);
 		vol = Q_atof(Cmd_Argv(i + 1));
 		S_StartSound(hash++, 0, sfx, listener_origin, vol, 1.0);
