@@ -556,9 +556,6 @@ LINE TESTING IN HULLS
 ===============================================================================
 */
 
-// 1/32 epsilon to keep floating point happy
-#define	DIST_EPSILON	(0.03125)
-
 /*
 ==================
 SV_RecursiveHullCheck
